; Freeciv Windows installer script
; some parts adapted from Wesnoth installer script

SetCompressor /SOLID lzma

!define APPNAME "Freeciv"
!define VERSION 2.3.0-beta4
!define GUI_ID gtk2
!define GUI_NAME GTK+
!define APPID "${APPNAME}-${VERSION}-${GUI_ID}"

!define MULTIUSER_EXECUTIONLEVEL Highest
!define MULTIUSER_MUI
!define MULTIUSER_INSTALLMODE_COMMANDLINE
!define MULTIUSER_INSTALLMODE_DEFAULT_REGISTRY_KEY "Software\${APPNAME}\${VERSION}\${GUI_ID}"
!define MULTIUSER_INSTALLMODE_DEFAULT_REGISTRY_VALUENAME ""
!define MULTIUSER_INSTALLMODE_INSTDIR_REGISTRY_KEY "Software\${APPNAME}\${VERSION}\${GUI_ID}"
!define MULTIUSER_INSTALLMODE_INSTDIR_REGISTRY_VALUENAME ""
!define MULTIUSER_INSTALLMODE_INSTDIR "${APPNAME}-${VERSION}-${GUI_ID}"

!include "MultiUser.nsh"
!include "MUI2.nsh"

;General

Name "${APPNAME} ${VERSION} (${GUI_NAME} client)"
OutFile "Output/${APPNAME}-${VERSION}-win32-${GUI_ID}-setup.exe"

;Variables

Var STARTMENU_FOLDER

; Pages

!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "freeciv\COPYING"
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MULTIUSER_PAGE_INSTALLMODE
!insertmacro MUI_PAGE_DIRECTORY

;Start Menu Folder Page Configuration
!define MUI_STARTMENUPAGE_REGISTRY_ROOT "SHCTX" 
!define MUI_STARTMENUPAGE_REGISTRY_KEY "Software\${APPNAME}\${VERSION}\${GUI_ID}" 
!define MUI_STARTMENUPAGE_REGISTRY_VALUENAME "Start Menu Folder"
!define MUI_STARTMENUPAGE_DEFAULTFOLDER "$(^Name)"

!insertmacro MUI_PAGE_STARTMENU "Application" $STARTMENU_FOLDER
!insertmacro MUI_PAGE_INSTFILES

!define MUI_FINISHPAGE_RUN "$INSTDIR\freeciv-gtk2.exe"
!insertmacro MUI_PAGE_FINISH

!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES

;Languages

!insertmacro MUI_LANGUAGE "English"

; The stuff to install
Section "${APPNAME} (required)"

  SectionIn RO

  SetOutPath $INSTDIR
  File /nonfatal /r /x locale /x stdsounds.soundspec /x stdsounds freeciv\*.*

  ; Write the installation path into the registry
  WriteRegStr "SHCTX" SOFTWARE\${APPNAME}\${VERSION}\${GUI_ID} "" "$INSTDIR"

  !insertmacro MUI_STARTMENU_WRITE_BEGIN Application
  CreateDirectory "$SMPROGRAMS\$STARTMENU_FOLDER"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Freeciv Server.lnk" "$INSTDIR\freeciv-server.exe"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Freeciv.lnk" "$INSTDIR\freeciv-gtk2.exe"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Uninstall.lnk" "$INSTDIR\uninstall.exe"
  CreateShortCut "$SMPROGRAMS\$STARTMENU_FOLDER\Website.lnk" "$INSTDIR\Freeciv.url"
  !insertmacro MUI_STARTMENU_WRITE_END

  ; Write the uninstall keys for Windows
  WriteRegStr "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "DisplayName" "$(^Name)"
  WriteRegStr "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "UninstallString" '"$INSTDIR\uninstall.exe"'
  WriteRegDWORD "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "NoModify" 1
  WriteRegDWORD "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}" "NoRepair" 1
  WriteUninstaller "uninstall.exe"
  
  SetOutPath $INSTDIR
SectionEnd

SectionGroup "Soundsets"

  Section "stdsounds"
  SetOutPath $INSTDIR\data
  File /r freeciv\data\stdsounds.soundspec
  SetOutPath $INSTDIR\data\stdsounds
  File /r freeciv\data\stdsounds\*.*
  SetOutPath $INSTDIR
  SectionEnd

SectionGroupEnd

SectionGroup "Additional languages"

  Section /o "ar"
  SetOutPath $INSTDIR\share\locale\ar
  File /r freeciv\share\locale\ar\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ca"
  SetOutPath $INSTDIR\share\locale\ca
  File /r freeciv\share\locale\ca\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "cs"
  SetOutPath $INSTDIR\share\locale\cs
  File /r freeciv\share\locale\cs\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "da"
  SetOutPath $INSTDIR\share\locale\da
  File /r freeciv\share\locale\da\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "de"
  SetOutPath $INSTDIR\share\locale\de
  File /r freeciv\share\locale\de\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "el"
  SetOutPath $INSTDIR\share\locale\el
  File /r freeciv\share\locale\el\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "en_GB"
  SetOutPath $INSTDIR\share\locale\en_GB
  File /r freeciv\share\locale\en_GB\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "eo"
  SetOutPath $INSTDIR\share\locale\eo
  File /r freeciv\share\locale\eo\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "es"
  SetOutPath $INSTDIR\share\locale\es
  File /r freeciv\share\locale\es\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "et"
  SetOutPath $INSTDIR\share\locale\et
  File /r freeciv\share\locale\et\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "fa"
  SetOutPath $INSTDIR\share\locale\fa
  File /r freeciv\share\locale\fa\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "fi"
  SetOutPath $INSTDIR\share\locale\fi
  File /r freeciv\share\locale\fi\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "fr"
  SetOutPath $INSTDIR\share\locale\fr
  File /r freeciv\share\locale\fr\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ga"
  SetOutPath $INSTDIR\share\locale\ga
  File /r freeciv\share\locale\ga\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "he"
  SetOutPath $INSTDIR\share\locale\he
  File /r freeciv\share\locale\he\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "hu"
  SetOutPath $INSTDIR\share\locale\hu
  File /r freeciv\share\locale\hu\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "it"
  SetOutPath $INSTDIR\share\locale\it
  File /r freeciv\share\locale\it\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ja"
  SetOutPath $INSTDIR\share\locale\ja
  File /r freeciv\share\locale\ja\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ko"
  SetOutPath $INSTDIR\share\locale\ko
  File /r freeciv\share\locale\ko\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "lt"
  SetOutPath $INSTDIR\share\locale\lt
  File /r freeciv\share\locale\lt\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "nb"
  SetOutPath $INSTDIR\share\locale\nb
  File /r freeciv\share\locale\nb\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "nl"
  SetOutPath $INSTDIR\share\locale\nl
  File /r freeciv\share\locale\nl\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "no"
  SetOutPath $INSTDIR\share\locale\no
  File /r freeciv\share\locale\no\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "pl"
  SetOutPath $INSTDIR\share\locale\pl
  File /r freeciv\share\locale\pl\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "pt"
  SetOutPath $INSTDIR\share\locale\pt
  File /r freeciv\share\locale\pt\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "pt_BR"
  SetOutPath $INSTDIR\share\locale\pt_BR
  File /r freeciv\share\locale\pt_BR\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ro"
  SetOutPath $INSTDIR\share\locale\ro
  File /r freeciv\share\locale\ro\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "ru"
  SetOutPath $INSTDIR\share\locale\ru
  File /r freeciv\share\locale\ru\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "sv"
  SetOutPath $INSTDIR\share\locale\sv
  File /r freeciv\share\locale\sv\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "tr"
  SetOutPath $INSTDIR\share\locale\tr
  File /r freeciv\share\locale\tr\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "uk"
  SetOutPath $INSTDIR\share\locale\uk
  File /r freeciv\share\locale\uk\*.*
  SetOutPath $INSTDIR
  SectionEnd

  Section /o "zh_CN"
  SetOutPath $INSTDIR\share\locale\zh_CN
  File /r freeciv\share\locale\zh_CN\*.*
  SetOutPath $INSTDIR
  SectionEnd

SectionGroupEnd

;--------------------------------
;Installer Functions

Function .onInit

  !insertmacro MULTIUSER_INIT

FunctionEnd

; special uninstall section.
Section "Uninstall"

  ; remove files
  Delete "$INSTDIR\ABOUT-NLS"
  Delete "$INSTDIR\AUTHORS"
  Delete "$INSTDIR\ChangeLog"
  Delete "$INSTDIR\COPYING"
  Delete "$INSTDIR\data\amplio2\ancientcities.png"
  Delete "$INSTDIR\data\amplio2\ancientcities.spec"
  Delete "$INSTDIR\data\amplio2\explosions.png"
  Delete "$INSTDIR\data\amplio2\explosions.spec"
  Delete "$INSTDIR\data\amplio2\fog.png"
  Delete "$INSTDIR\data\amplio2\fog.spec"
  Delete "$INSTDIR\data\amplio2\grid.png"
  Delete "$INSTDIR\data\amplio2\grid.spec"
  Delete "$INSTDIR\data\amplio2\hills.png"
  Delete "$INSTDIR\data\amplio2\hills.spec"
  Delete "$INSTDIR\data\amplio2\medievalcities.png"
  Delete "$INSTDIR\data\amplio2\medievalcities.spec"
  Delete "$INSTDIR\data\amplio2\moderncities.png"
  Delete "$INSTDIR\data\amplio2\moderncities.spec"
  Delete "$INSTDIR\data\amplio2\mountains.png"
  Delete "$INSTDIR\data\amplio2\mountains.spec"
  Delete "$INSTDIR\data\amplio2\nuke.png"
  Delete "$INSTDIR\data\amplio2\nuke.spec"
  Delete "$INSTDIR\data\amplio2\ocean.png"
  Delete "$INSTDIR\data\amplio2\ocean.spec"
  Delete "$INSTDIR\data\amplio2\select-alpha.png"
  Delete "$INSTDIR\data\amplio2\select.png"
  Delete "$INSTDIR\data\amplio2\select.spec"
  Delete "$INSTDIR\data\amplio2\terrain1.png"
  Delete "$INSTDIR\data\amplio2\terrain1.spec"
  Delete "$INSTDIR\data\amplio2\terrain2.png"
  Delete "$INSTDIR\data\amplio2\terrain2.spec"
  Delete "$INSTDIR\data\amplio2\tiles.png"
  Delete "$INSTDIR\data\amplio2\tiles.spec"
  Delete "$INSTDIR\data\amplio2\units.png"
  Delete "$INSTDIR\data\amplio2\units.spec"
  Delete "$INSTDIR\data\amplio2\water.png"
  Delete "$INSTDIR\data\amplio2\water.spec"
  Delete "$INSTDIR\data\amplio2.tilespec"
  Delete "$INSTDIR\data\buildings\airport.png"
  Delete "$INSTDIR\data\buildings\aqueduct.png"
  Delete "$INSTDIR\data\buildings\bank.png"
  Delete "$INSTDIR\data\buildings\barracks_i.png"
  Delete "$INSTDIR\data\buildings\barracks_ii.png"
  Delete "$INSTDIR\data\buildings\barracks_iii.png"
  Delete "$INSTDIR\data\buildings\capitalization.png"
  Delete "$INSTDIR\data\buildings\cathedral.png"
  Delete "$INSTDIR\data\buildings\city_walls.png"
  Delete "$INSTDIR\data\buildings\coastal_defense.png"
  Delete "$INSTDIR\data\buildings\colosseum.png"
  Delete "$INSTDIR\data\buildings\courthouse.png"
  Delete "$INSTDIR\data\buildings\factory.png"
  Delete "$INSTDIR\data\buildings\granary.png"
  Delete "$INSTDIR\data\buildings\harbor.png"
  Delete "$INSTDIR\data\buildings\hydro_plant.png"
  Delete "$INSTDIR\data\buildings\library.png"
  Delete "$INSTDIR\data\buildings\marketplace.png"
  Delete "$INSTDIR\data\buildings\mass_transit.png"
  Delete "$INSTDIR\data\buildings\mfg_plant.png"
  Delete "$INSTDIR\data\buildings\nuclear_plant.png"
  Delete "$INSTDIR\data\buildings\offshore_platform.png"
  Delete "$INSTDIR\data\buildings\palace.png"
  Delete "$INSTDIR\data\buildings\police_station.png"
  Delete "$INSTDIR\data\buildings\port_facility.png"
  Delete "$INSTDIR\data\buildings\power_plant.png"
  Delete "$INSTDIR\data\buildings\recycling_center.png"
  Delete "$INSTDIR\data\buildings\research_lab.png"
  Delete "$INSTDIR\data\buildings\sam_battery.png"
  Delete "$INSTDIR\data\buildings\sdi_defense.png"
  Delete "$INSTDIR\data\buildings\sewer_system.png"
  Delete "$INSTDIR\data\buildings\solar_plant.png"
  Delete "$INSTDIR\data\buildings\space_component.png"
  Delete "$INSTDIR\data\buildings\space_modules.png"
  Delete "$INSTDIR\data\buildings\space_structural.png"
  Delete "$INSTDIR\data\buildings\stock_exchange.png"
  Delete "$INSTDIR\data\buildings\supermarket.png"
  Delete "$INSTDIR\data\buildings\super_highways.png"
  Delete "$INSTDIR\data\buildings\temple.png"
  Delete "$INSTDIR\data\buildings\university.png"
  Delete "$INSTDIR\data\civ1\buildings.ruleset"
  Delete "$INSTDIR\data\civ1\cities.ruleset"
  Delete "$INSTDIR\data\civ1\effects.ruleset"
  Delete "$INSTDIR\data\civ1\game.ruleset"
  Delete "$INSTDIR\data\civ1\governments.ruleset"
  Delete "$INSTDIR\data\civ1\nations.ruleset"
  Delete "$INSTDIR\data\civ1\techs.ruleset"
  Delete "$INSTDIR\data\civ1\terrain.ruleset"
  Delete "$INSTDIR\data\civ1\units.ruleset"
  Delete "$INSTDIR\data\civ1.serv"
  Delete "$INSTDIR\data\civ2\buildings.ruleset"
  Delete "$INSTDIR\data\civ2\cities.ruleset"
  Delete "$INSTDIR\data\civ2\effects.ruleset"
  Delete "$INSTDIR\data\civ2\game.ruleset"
  Delete "$INSTDIR\data\civ2\governments.ruleset"
  Delete "$INSTDIR\data\civ2\techs.ruleset"
  Delete "$INSTDIR\data\civ2\terrain.ruleset"
  Delete "$INSTDIR\data\civ2\units.ruleset"
  Delete "$INSTDIR\data\civ2.serv"
  Delete "$INSTDIR\data\default\ai_effects.ruleset"
  Delete "$INSTDIR\data\default\buildings.ruleset"
  Delete "$INSTDIR\data\default\cities.ruleset"
  Delete "$INSTDIR\data\default\default.lua"
  Delete "$INSTDIR\data\default\effects.ruleset"
  Delete "$INSTDIR\data\default\game.ruleset"
  Delete "$INSTDIR\data\default\governments.ruleset"
  Delete "$INSTDIR\data\default\nations.ruleset"
  Delete "$INSTDIR\data\default\script.lua"
  Delete "$INSTDIR\data\default\techs.ruleset"
  Delete "$INSTDIR\data\default\terrain.ruleset"
  Delete "$INSTDIR\data\default\units.ruleset"
  Delete "$INSTDIR\data\default.serv"
  Delete "$INSTDIR\data\experimental\ai_effects.ruleset"
  Delete "$INSTDIR\data\experimental\buildings.ruleset"
  Delete "$INSTDIR\data\experimental\cities.ruleset"
  Delete "$INSTDIR\data\experimental\effects.ruleset"
  Delete "$INSTDIR\data\experimental\game.ruleset"
  Delete "$INSTDIR\data\experimental\governments.ruleset"
  Delete "$INSTDIR\data\experimental\script.lua"
  Delete "$INSTDIR\data\experimental\techs.ruleset"
  Delete "$INSTDIR\data\experimental\terrain.ruleset"
  Delete "$INSTDIR\data\experimental\units.ruleset"
  Delete "$INSTDIR\data\experimental.serv"
  Delete "$INSTDIR\data\flags\abkhazia-large.png"
  Delete "$INSTDIR\data\flags\abkhazia-shield-large.png"
  Delete "$INSTDIR\data\flags\abkhazia-shield.png"
  Delete "$INSTDIR\data\flags\abkhazia.png"
  Delete "$INSTDIR\data\flags\aborigines-large.png"
  Delete "$INSTDIR\data\flags\aborigines-shield-large.png"
  Delete "$INSTDIR\data\flags\aborigines-shield.png"
  Delete "$INSTDIR\data\flags\aborigines.png"
  Delete "$INSTDIR\data\flags\acadia-large.png"
  Delete "$INSTDIR\data\flags\acadia-shield-large.png"
  Delete "$INSTDIR\data\flags\acadia-shield.png"
  Delete "$INSTDIR\data\flags\acadia.png"
  Delete "$INSTDIR\data\flags\aceh-large.png"
  Delete "$INSTDIR\data\flags\aceh-shield-large.png"
  Delete "$INSTDIR\data\flags\aceh-shield.png"
  Delete "$INSTDIR\data\flags\aceh.png"
  Delete "$INSTDIR\data\flags\afghanistan-large.png"
  Delete "$INSTDIR\data\flags\afghanistan-shield-large.png"
  Delete "$INSTDIR\data\flags\afghanistan-shield.png"
  Delete "$INSTDIR\data\flags\afghanistan.png"
  Delete "$INSTDIR\data\flags\ainu-large.png"
  Delete "$INSTDIR\data\flags\ainu-shield-large.png"
  Delete "$INSTDIR\data\flags\ainu-shield.png"
  Delete "$INSTDIR\data\flags\ainu.png"
  Delete "$INSTDIR\data\flags\akwe-large.png"
  Delete "$INSTDIR\data\flags\akwe-shield-large.png"
  Delete "$INSTDIR\data\flags\akwe-shield.png"
  Delete "$INSTDIR\data\flags\akwe.png"
  Delete "$INSTDIR\data\flags\albania-large.png"
  Delete "$INSTDIR\data\flags\albania-shield-large.png"
  Delete "$INSTDIR\data\flags\albania-shield.png"
  Delete "$INSTDIR\data\flags\albania.png"
  Delete "$INSTDIR\data\flags\aleut-large.png"
  Delete "$INSTDIR\data\flags\aleut-shield-large.png"
  Delete "$INSTDIR\data\flags\aleut-shield.png"
  Delete "$INSTDIR\data\flags\aleut.png"
  Delete "$INSTDIR\data\flags\algeria-large.png"
  Delete "$INSTDIR\data\flags\algeria-shield-large.png"
  Delete "$INSTDIR\data\flags\algeria-shield.png"
  Delete "$INSTDIR\data\flags\algeria.png"
  Delete "$INSTDIR\data\flags\almohad-large.png"
  Delete "$INSTDIR\data\flags\almohad-shield-large.png"
  Delete "$INSTDIR\data\flags\almohad-shield.png"
  Delete "$INSTDIR\data\flags\almohad.png"
  Delete "$INSTDIR\data\flags\amazigh-large.png"
  Delete "$INSTDIR\data\flags\amazigh-shield-large.png"
  Delete "$INSTDIR\data\flags\amazigh-shield.png"
  Delete "$INSTDIR\data\flags\amazigh.png"
  Delete "$INSTDIR\data\flags\amazon-large.png"
  Delete "$INSTDIR\data\flags\amazon-shield-large.png"
  Delete "$INSTDIR\data\flags\amazon-shield.png"
  Delete "$INSTDIR\data\flags\amazon.png"
  Delete "$INSTDIR\data\flags\andorra-large.png"
  Delete "$INSTDIR\data\flags\andorra-shield-large.png"
  Delete "$INSTDIR\data\flags\andorra-shield.png"
  Delete "$INSTDIR\data\flags\andorra.png"
  Delete "$INSTDIR\data\flags\angola-large.png"
  Delete "$INSTDIR\data\flags\angola-shield-large.png"
  Delete "$INSTDIR\data\flags\angola-shield.png"
  Delete "$INSTDIR\data\flags\angola.png"
  Delete "$INSTDIR\data\flags\anishinaabe-large.png"
  Delete "$INSTDIR\data\flags\anishinaabe-shield-large.png"
  Delete "$INSTDIR\data\flags\anishinaabe-shield.png"
  Delete "$INSTDIR\data\flags\anishinaabe.png"
  Delete "$INSTDIR\data\flags\antarctica-large.png"
  Delete "$INSTDIR\data\flags\antarctica-shield-large.png"
  Delete "$INSTDIR\data\flags\antarctica-shield.png"
  Delete "$INSTDIR\data\flags\antarctica.png"
  Delete "$INSTDIR\data\flags\antarctica_alt-large.png"
  Delete "$INSTDIR\data\flags\antarctica_alt-shield-large.png"
  Delete "$INSTDIR\data\flags\antarctica_alt-shield.png"
  Delete "$INSTDIR\data\flags\antarctica_alt.png"
  Delete "$INSTDIR\data\flags\apache-large.png"
  Delete "$INSTDIR\data\flags\apache-shield-large.png"
  Delete "$INSTDIR\data\flags\apache-shield.png"
  Delete "$INSTDIR\data\flags\apache.png"
  Delete "$INSTDIR\data\flags\arab-large.png"
  Delete "$INSTDIR\data\flags\arab-shield-large.png"
  Delete "$INSTDIR\data\flags\arab-shield.png"
  Delete "$INSTDIR\data\flags\arab.png"
  Delete "$INSTDIR\data\flags\aragon-large.png"
  Delete "$INSTDIR\data\flags\aragon-shield-large.png"
  Delete "$INSTDIR\data\flags\aragon-shield.png"
  Delete "$INSTDIR\data\flags\aragon.png"
  Delete "$INSTDIR\data\flags\aram-large.png"
  Delete "$INSTDIR\data\flags\aram-shield-large.png"
  Delete "$INSTDIR\data\flags\aram-shield.png"
  Delete "$INSTDIR\data\flags\aram.png"
  Delete "$INSTDIR\data\flags\argentina-large.png"
  Delete "$INSTDIR\data\flags\argentina-shield-large.png"
  Delete "$INSTDIR\data\flags\argentina-shield.png"
  Delete "$INSTDIR\data\flags\argentina.png"
  Delete "$INSTDIR\data\flags\armenia-large.png"
  Delete "$INSTDIR\data\flags\armenia-shield-large.png"
  Delete "$INSTDIR\data\flags\armenia-shield.png"
  Delete "$INSTDIR\data\flags\armenia.png"
  Delete "$INSTDIR\data\flags\ashanti-large.png"
  Delete "$INSTDIR\data\flags\ashanti-shield-large.png"
  Delete "$INSTDIR\data\flags\ashanti-shield.png"
  Delete "$INSTDIR\data\flags\ashanti.png"
  Delete "$INSTDIR\data\flags\assyria-large.png"
  Delete "$INSTDIR\data\flags\assyria-shield-large.png"
  Delete "$INSTDIR\data\flags\assyria-shield.png"
  Delete "$INSTDIR\data\flags\assyria.png"
  Delete "$INSTDIR\data\flags\asturias-large.png"
  Delete "$INSTDIR\data\flags\asturias-shield-large.png"
  Delete "$INSTDIR\data\flags\asturias-shield.png"
  Delete "$INSTDIR\data\flags\asturias.png"
  Delete "$INSTDIR\data\flags\atlantis-large.png"
  Delete "$INSTDIR\data\flags\atlantis-shield-large.png"
  Delete "$INSTDIR\data\flags\atlantis-shield.png"
  Delete "$INSTDIR\data\flags\atlantis.png"
  Delete "$INSTDIR\data\flags\australia-large.png"
  Delete "$INSTDIR\data\flags\australia-shield-large.png"
  Delete "$INSTDIR\data\flags\australia-shield.png"
  Delete "$INSTDIR\data\flags\australia.png"
  Delete "$INSTDIR\data\flags\austria-large.png"
  Delete "$INSTDIR\data\flags\austria-shield-large.png"
  Delete "$INSTDIR\data\flags\austria-shield.png"
  Delete "$INSTDIR\data\flags\austria.png"
  Delete "$INSTDIR\data\flags\aymara-large.png"
  Delete "$INSTDIR\data\flags\aymara-shield-large.png"
  Delete "$INSTDIR\data\flags\aymara-shield.png"
  Delete "$INSTDIR\data\flags\aymara.png"
  Delete "$INSTDIR\data\flags\azerbaijan-large.png"
  Delete "$INSTDIR\data\flags\azerbaijan-shield-large.png"
  Delete "$INSTDIR\data\flags\azerbaijan-shield.png"
  Delete "$INSTDIR\data\flags\azerbaijan.png"
  Delete "$INSTDIR\data\flags\aztec-large.png"
  Delete "$INSTDIR\data\flags\aztec-shield-large.png"
  Delete "$INSTDIR\data\flags\aztec-shield.png"
  Delete "$INSTDIR\data\flags\aztec.png"
  Delete "$INSTDIR\data\flags\babylon-large.png"
  Delete "$INSTDIR\data\flags\babylon-shield-large.png"
  Delete "$INSTDIR\data\flags\babylon-shield.png"
  Delete "$INSTDIR\data\flags\babylon.png"
  Delete "$INSTDIR\data\flags\baden-large.png"
  Delete "$INSTDIR\data\flags\baden-shield-large.png"
  Delete "$INSTDIR\data\flags\baden-shield.png"
  Delete "$INSTDIR\data\flags\baden.png"
  Delete "$INSTDIR\data\flags\bangladesh-large.png"
  Delete "$INSTDIR\data\flags\bangladesh-shield-large.png"
  Delete "$INSTDIR\data\flags\bangladesh-shield.png"
  Delete "$INSTDIR\data\flags\bangladesh.png"
  Delete "$INSTDIR\data\flags\barbarian-large.png"
  Delete "$INSTDIR\data\flags\barbarian-shield-large.png"
  Delete "$INSTDIR\data\flags\barbarian-shield.png"
  Delete "$INSTDIR\data\flags\barbarian.png"
  Delete "$INSTDIR\data\flags\bashkortostan-large.png"
  Delete "$INSTDIR\data\flags\bashkortostan-shield-large.png"
  Delete "$INSTDIR\data\flags\bashkortostan-shield.png"
  Delete "$INSTDIR\data\flags\bashkortostan.png"
  Delete "$INSTDIR\data\flags\bavarian-large.png"
  Delete "$INSTDIR\data\flags\bavarian-shield-large.png"
  Delete "$INSTDIR\data\flags\bavarian-shield.png"
  Delete "$INSTDIR\data\flags\bavarian.png"
  Delete "$INSTDIR\data\flags\belarus-large.png"
  Delete "$INSTDIR\data\flags\belarus-shield-large.png"
  Delete "$INSTDIR\data\flags\belarus-shield.png"
  Delete "$INSTDIR\data\flags\belarus.png"
  Delete "$INSTDIR\data\flags\belgium-large.png"
  Delete "$INSTDIR\data\flags\belgium-shield-large.png"
  Delete "$INSTDIR\data\flags\belgium-shield.png"
  Delete "$INSTDIR\data\flags\belgium.png"
  Delete "$INSTDIR\data\flags\benin_ancient-large.png"
  Delete "$INSTDIR\data\flags\benin_ancient-shield-large.png"
  Delete "$INSTDIR\data\flags\benin_ancient-shield.png"
  Delete "$INSTDIR\data\flags\benin_ancient.png"
  Delete "$INSTDIR\data\flags\bhutan-large.png"
  Delete "$INSTDIR\data\flags\bhutan-shield-large.png"
  Delete "$INSTDIR\data\flags\bhutan-shield.png"
  Delete "$INSTDIR\data\flags\bhutan.png"
  Delete "$INSTDIR\data\flags\biafra-large.png"
  Delete "$INSTDIR\data\flags\biafra-shield-large.png"
  Delete "$INSTDIR\data\flags\biafra-shield.png"
  Delete "$INSTDIR\data\flags\biafra.png"
  Delete "$INSTDIR\data\flags\boer-large.png"
  Delete "$INSTDIR\data\flags\boer-shield-large.png"
  Delete "$INSTDIR\data\flags\boer-shield.png"
  Delete "$INSTDIR\data\flags\boer.png"
  Delete "$INSTDIR\data\flags\bolivia-large.png"
  Delete "$INSTDIR\data\flags\bolivia-shield-large.png"
  Delete "$INSTDIR\data\flags\bolivia-shield.png"
  Delete "$INSTDIR\data\flags\bolivia.png"
  Delete "$INSTDIR\data\flags\bosnia-large.png"
  Delete "$INSTDIR\data\flags\bosnia-shield-large.png"
  Delete "$INSTDIR\data\flags\bosnia-shield.png"
  Delete "$INSTDIR\data\flags\bosnia.png"
  Delete "$INSTDIR\data\flags\bosporus-large.png"
  Delete "$INSTDIR\data\flags\bosporus-shield-large.png"
  Delete "$INSTDIR\data\flags\bosporus-shield.png"
  Delete "$INSTDIR\data\flags\bosporus.png"
  Delete "$INSTDIR\data\flags\botswana-large.png"
  Delete "$INSTDIR\data\flags\botswana-shield-large.png"
  Delete "$INSTDIR\data\flags\botswana-shield.png"
  Delete "$INSTDIR\data\flags\botswana.png"
  Delete "$INSTDIR\data\flags\brandenburg-large.png"
  Delete "$INSTDIR\data\flags\brandenburg-shield-large.png"
  Delete "$INSTDIR\data\flags\brandenburg-shield.png"
  Delete "$INSTDIR\data\flags\brandenburg.png"
  Delete "$INSTDIR\data\flags\brasil-large.png"
  Delete "$INSTDIR\data\flags\brasil-shield-large.png"
  Delete "$INSTDIR\data\flags\brasil-shield.png"
  Delete "$INSTDIR\data\flags\brasil.png"
  Delete "$INSTDIR\data\flags\britannia-large.png"
  Delete "$INSTDIR\data\flags\britannia-shield-large.png"
  Delete "$INSTDIR\data\flags\britannia-shield.png"
  Delete "$INSTDIR\data\flags\britannia.png"
  Delete "$INSTDIR\data\flags\brittany-large.png"
  Delete "$INSTDIR\data\flags\brittany-shield-large.png"
  Delete "$INSTDIR\data\flags\brittany-shield.png"
  Delete "$INSTDIR\data\flags\brittany.png"
  Delete "$INSTDIR\data\flags\bulgaria-large.png"
  Delete "$INSTDIR\data\flags\bulgaria-shield-large.png"
  Delete "$INSTDIR\data\flags\bulgaria-shield.png"
  Delete "$INSTDIR\data\flags\bulgaria.png"
  Delete "$INSTDIR\data\flags\burgundy-large.png"
  Delete "$INSTDIR\data\flags\burgundy-shield-large.png"
  Delete "$INSTDIR\data\flags\burgundy-shield.png"
  Delete "$INSTDIR\data\flags\burgundy.png"
  Delete "$INSTDIR\data\flags\burkina_faso-large.png"
  Delete "$INSTDIR\data\flags\burkina_faso-shield-large.png"
  Delete "$INSTDIR\data\flags\burkina_faso-shield.png"
  Delete "$INSTDIR\data\flags\burkina_faso.png"
  Delete "$INSTDIR\data\flags\burundi-large.png"
  Delete "$INSTDIR\data\flags\burundi-shield-large.png"
  Delete "$INSTDIR\data\flags\burundi-shield.png"
  Delete "$INSTDIR\data\flags\burundi.png"
  Delete "$INSTDIR\data\flags\byzantium-large.png"
  Delete "$INSTDIR\data\flags\byzantium-shield-large.png"
  Delete "$INSTDIR\data\flags\byzantium-shield.png"
  Delete "$INSTDIR\data\flags\byzantium.png"
  Delete "$INSTDIR\data\flags\caddo-large.png"
  Delete "$INSTDIR\data\flags\caddo-shield-large.png"
  Delete "$INSTDIR\data\flags\caddo-shield.png"
  Delete "$INSTDIR\data\flags\caddo.png"
  Delete "$INSTDIR\data\flags\california-large.png"
  Delete "$INSTDIR\data\flags\california-shield-large.png"
  Delete "$INSTDIR\data\flags\california-shield.png"
  Delete "$INSTDIR\data\flags\california.png"
  Delete "$INSTDIR\data\flags\cameroon-large.png"
  Delete "$INSTDIR\data\flags\cameroon-shield-large.png"
  Delete "$INSTDIR\data\flags\cameroon-shield.png"
  Delete "$INSTDIR\data\flags\cameroon.png"
  Delete "$INSTDIR\data\flags\canada-large.png"
  Delete "$INSTDIR\data\flags\canada-shield-large.png"
  Delete "$INSTDIR\data\flags\canada-shield.png"
  Delete "$INSTDIR\data\flags\canada.png"
  Delete "$INSTDIR\data\flags\canada_old-large.png"
  Delete "$INSTDIR\data\flags\canada_old-shield-large.png"
  Delete "$INSTDIR\data\flags\canada_old-shield.png"
  Delete "$INSTDIR\data\flags\canada_old.png"
  Delete "$INSTDIR\data\flags\car-large.png"
  Delete "$INSTDIR\data\flags\car-shield-large.png"
  Delete "$INSTDIR\data\flags\car-shield.png"
  Delete "$INSTDIR\data\flags\car.png"
  Delete "$INSTDIR\data\flags\cartago-large.png"
  Delete "$INSTDIR\data\flags\cartago-shield-large.png"
  Delete "$INSTDIR\data\flags\cartago-shield.png"
  Delete "$INSTDIR\data\flags\cartago.png"
  Delete "$INSTDIR\data\flags\castile-large.png"
  Delete "$INSTDIR\data\flags\castile-shield-large.png"
  Delete "$INSTDIR\data\flags\castile-shield.png"
  Delete "$INSTDIR\data\flags\castile.png"
  Delete "$INSTDIR\data\flags\catalan-large.png"
  Delete "$INSTDIR\data\flags\catalan-shield-large.png"
  Delete "$INSTDIR\data\flags\catalan-shield.png"
  Delete "$INSTDIR\data\flags\catalan.png"
  Delete "$INSTDIR\data\flags\celtiberian-large.png"
  Delete "$INSTDIR\data\flags\celtiberian-shield-large.png"
  Delete "$INSTDIR\data\flags\celtiberian-shield.png"
  Delete "$INSTDIR\data\flags\celtiberian.png"
  Delete "$INSTDIR\data\flags\central_america-large.png"
  Delete "$INSTDIR\data\flags\central_america-shield-large.png"
  Delete "$INSTDIR\data\flags\central_america-shield.png"
  Delete "$INSTDIR\data\flags\central_america.png"
  Delete "$INSTDIR\data\flags\cham-large.png"
  Delete "$INSTDIR\data\flags\cham-shield-large.png"
  Delete "$INSTDIR\data\flags\cham-shield.png"
  Delete "$INSTDIR\data\flags\cham.png"
  Delete "$INSTDIR\data\flags\chananea-large.png"
  Delete "$INSTDIR\data\flags\chananea-shield-large.png"
  Delete "$INSTDIR\data\flags\chananea-shield.png"
  Delete "$INSTDIR\data\flags\chananea.png"
  Delete "$INSTDIR\data\flags\chechnya-large.png"
  Delete "$INSTDIR\data\flags\chechnya-shield-large.png"
  Delete "$INSTDIR\data\flags\chechnya-shield.png"
  Delete "$INSTDIR\data\flags\chechnya.png"
  Delete "$INSTDIR\data\flags\cheyenne-large.png"
  Delete "$INSTDIR\data\flags\cheyenne-shield-large.png"
  Delete "$INSTDIR\data\flags\cheyenne-shield.png"
  Delete "$INSTDIR\data\flags\cheyenne.png"
  Delete "$INSTDIR\data\flags\chile-large.png"
  Delete "$INSTDIR\data\flags\chile-shield-large.png"
  Delete "$INSTDIR\data\flags\chile-shield.png"
  Delete "$INSTDIR\data\flags\chile.png"
  Delete "$INSTDIR\data\flags\chimu-large.png"
  Delete "$INSTDIR\data\flags\chimu-shield-large.png"
  Delete "$INSTDIR\data\flags\chimu-shield.png"
  Delete "$INSTDIR\data\flags\chimu.png"
  Delete "$INSTDIR\data\flags\china-large.png"
  Delete "$INSTDIR\data\flags\china-shield-large.png"
  Delete "$INSTDIR\data\flags\china-shield.png"
  Delete "$INSTDIR\data\flags\china.png"
  Delete "$INSTDIR\data\flags\chola-large.png"
  Delete "$INSTDIR\data\flags\chola-shield-large.png"
  Delete "$INSTDIR\data\flags\chola-shield.png"
  Delete "$INSTDIR\data\flags\chola.png"
  Delete "$INSTDIR\data\flags\chumash-large.png"
  Delete "$INSTDIR\data\flags\chumash-shield-large.png"
  Delete "$INSTDIR\data\flags\chumash-shield.png"
  Delete "$INSTDIR\data\flags\chumash.png"
  Delete "$INSTDIR\data\flags\colombia-large.png"
  Delete "$INSTDIR\data\flags\colombia-shield-large.png"
  Delete "$INSTDIR\data\flags\colombia-shield.png"
  Delete "$INSTDIR\data\flags\colombia.png"
  Delete "$INSTDIR\data\flags\comanche-large.png"
  Delete "$INSTDIR\data\flags\comanche-shield-large.png"
  Delete "$INSTDIR\data\flags\comanche-shield.png"
  Delete "$INSTDIR\data\flags\comanche.png"
  Delete "$INSTDIR\data\flags\constantine-large.png"
  Delete "$INSTDIR\data\flags\constantine-shield-large.png"
  Delete "$INSTDIR\data\flags\constantine-shield.png"
  Delete "$INSTDIR\data\flags\constantine.png"
  Delete "$INSTDIR\data\flags\cornwall-large.png"
  Delete "$INSTDIR\data\flags\cornwall-shield-large.png"
  Delete "$INSTDIR\data\flags\cornwall-shield.png"
  Delete "$INSTDIR\data\flags\cornwall.png"
  Delete "$INSTDIR\data\flags\corsica-large.png"
  Delete "$INSTDIR\data\flags\corsica-shield-large.png"
  Delete "$INSTDIR\data\flags\corsica-shield.png"
  Delete "$INSTDIR\data\flags\corsica.png"
  Delete "$INSTDIR\data\flags\cossack-large.png"
  Delete "$INSTDIR\data\flags\cossack-shield-large.png"
  Delete "$INSTDIR\data\flags\cossack-shield.png"
  Delete "$INSTDIR\data\flags\cossack.png"
  Delete "$INSTDIR\data\flags\costa_rica-large.png"
  Delete "$INSTDIR\data\flags\costa_rica-shield-large.png"
  Delete "$INSTDIR\data\flags\costa_rica-shield.png"
  Delete "$INSTDIR\data\flags\costa_rica.png"
  Delete "$INSTDIR\data\flags\courland-large.png"
  Delete "$INSTDIR\data\flags\courland-shield-large.png"
  Delete "$INSTDIR\data\flags\courland-shield.png"
  Delete "$INSTDIR\data\flags\courland.png"
  Delete "$INSTDIR\data\flags\crimean_tatar-large.png"
  Delete "$INSTDIR\data\flags\crimean_tatar-shield-large.png"
  Delete "$INSTDIR\data\flags\crimean_tatar-shield.png"
  Delete "$INSTDIR\data\flags\crimean_tatar.png"
  Delete "$INSTDIR\data\flags\croatia-large.png"
  Delete "$INSTDIR\data\flags\croatia-shield-large.png"
  Delete "$INSTDIR\data\flags\croatia-shield.png"
  Delete "$INSTDIR\data\flags\croatia.png"
  Delete "$INSTDIR\data\flags\cuba-large.png"
  Delete "$INSTDIR\data\flags\cuba-shield-large.png"
  Delete "$INSTDIR\data\flags\cuba-shield.png"
  Delete "$INSTDIR\data\flags\cuba.png"
  Delete "$INSTDIR\data\flags\cyprus-large.png"
  Delete "$INSTDIR\data\flags\cyprus-shield-large.png"
  Delete "$INSTDIR\data\flags\cyprus-shield.png"
  Delete "$INSTDIR\data\flags\cyprus.png"
  Delete "$INSTDIR\data\flags\czech-large.png"
  Delete "$INSTDIR\data\flags\czech-shield-large.png"
  Delete "$INSTDIR\data\flags\czech-shield.png"
  Delete "$INSTDIR\data\flags\czech.png"
  Delete "$INSTDIR\data\flags\dahomey-large.png"
  Delete "$INSTDIR\data\flags\dahomey-shield-large.png"
  Delete "$INSTDIR\data\flags\dahomey-shield.png"
  Delete "$INSTDIR\data\flags\dahomey.png"
  Delete "$INSTDIR\data\flags\ddr-large.png"
  Delete "$INSTDIR\data\flags\ddr-shield-large.png"
  Delete "$INSTDIR\data\flags\ddr-shield.png"
  Delete "$INSTDIR\data\flags\ddr.png"
  Delete "$INSTDIR\data\flags\denmark-large.png"
  Delete "$INSTDIR\data\flags\denmark-shield-large.png"
  Delete "$INSTDIR\data\flags\denmark-shield.png"
  Delete "$INSTDIR\data\flags\denmark.png"
  Delete "$INSTDIR\data\flags\dominica-large.png"
  Delete "$INSTDIR\data\flags\dominica-shield-large.png"
  Delete "$INSTDIR\data\flags\dominica-shield.png"
  Delete "$INSTDIR\data\flags\dominica.png"
  Delete "$INSTDIR\data\flags\dominican_republic-large.png"
  Delete "$INSTDIR\data\flags\dominican_republic-shield-large.png"
  Delete "$INSTDIR\data\flags\dominican_republic-shield.png"
  Delete "$INSTDIR\data\flags\dominican_republic.png"
  Delete "$INSTDIR\data\flags\dryad-large.png"
  Delete "$INSTDIR\data\flags\dryad-shield-large.png"
  Delete "$INSTDIR\data\flags\dryad-shield.png"
  Delete "$INSTDIR\data\flags\dryad.png"
  Delete "$INSTDIR\data\flags\dr_congo-large.png"
  Delete "$INSTDIR\data\flags\dr_congo-shield-large.png"
  Delete "$INSTDIR\data\flags\dr_congo-shield.png"
  Delete "$INSTDIR\data\flags\dr_congo.png"
  Delete "$INSTDIR\data\flags\east_timor-large.png"
  Delete "$INSTDIR\data\flags\east_timor-shield-large.png"
  Delete "$INSTDIR\data\flags\east_timor-shield.png"
  Delete "$INSTDIR\data\flags\east_timor.png"
  Delete "$INSTDIR\data\flags\ecuador-large.png"
  Delete "$INSTDIR\data\flags\ecuador-shield-large.png"
  Delete "$INSTDIR\data\flags\ecuador-shield.png"
  Delete "$INSTDIR\data\flags\ecuador.png"
  Delete "$INSTDIR\data\flags\egypt-large.png"
  Delete "$INSTDIR\data\flags\egypt-shield-large.png"
  Delete "$INSTDIR\data\flags\egypt-shield.png"
  Delete "$INSTDIR\data\flags\egypt.png"
  Delete "$INSTDIR\data\flags\egypt_ancient-large.png"
  Delete "$INSTDIR\data\flags\egypt_ancient-shield-large.png"
  Delete "$INSTDIR\data\flags\egypt_ancient-shield.png"
  Delete "$INSTDIR\data\flags\egypt_ancient.png"
  Delete "$INSTDIR\data\flags\elam-large.png"
  Delete "$INSTDIR\data\flags\elam-shield-large.png"
  Delete "$INSTDIR\data\flags\elam-shield.png"
  Delete "$INSTDIR\data\flags\elam.png"
  Delete "$INSTDIR\data\flags\el_salvador-large.png"
  Delete "$INSTDIR\data\flags\el_salvador-shield-large.png"
  Delete "$INSTDIR\data\flags\el_salvador-shield.png"
  Delete "$INSTDIR\data\flags\el_salvador.png"
  Delete "$INSTDIR\data\flags\england-large.png"
  Delete "$INSTDIR\data\flags\england-shield-large.png"
  Delete "$INSTDIR\data\flags\england-shield.png"
  Delete "$INSTDIR\data\flags\england.png"
  Delete "$INSTDIR\data\flags\eritrea-large.png"
  Delete "$INSTDIR\data\flags\eritrea-shield-large.png"
  Delete "$INSTDIR\data\flags\eritrea-shield.png"
  Delete "$INSTDIR\data\flags\eritrea.png"
  Delete "$INSTDIR\data\flags\esperanto-large.png"
  Delete "$INSTDIR\data\flags\esperanto-shield-large.png"
  Delete "$INSTDIR\data\flags\esperanto-shield.png"
  Delete "$INSTDIR\data\flags\esperanto.png"
  Delete "$INSTDIR\data\flags\estonia-large.png"
  Delete "$INSTDIR\data\flags\estonia-shield-large.png"
  Delete "$INSTDIR\data\flags\estonia-shield.png"
  Delete "$INSTDIR\data\flags\estonia.png"
  Delete "$INSTDIR\data\flags\ethiopia-large.png"
  Delete "$INSTDIR\data\flags\ethiopia-shield-large.png"
  Delete "$INSTDIR\data\flags\ethiopia-shield.png"
  Delete "$INSTDIR\data\flags\ethiopia.png"
  Delete "$INSTDIR\data\flags\etruscan-large.png"
  Delete "$INSTDIR\data\flags\etruscan-shield-large.png"
  Delete "$INSTDIR\data\flags\etruscan-shield.png"
  Delete "$INSTDIR\data\flags\etruscan.png"
  Delete "$INSTDIR\data\flags\europe-large.png"
  Delete "$INSTDIR\data\flags\europe-shield-large.png"
  Delete "$INSTDIR\data\flags\europe-shield.png"
  Delete "$INSTDIR\data\flags\europe.png"
  Delete "$INSTDIR\data\flags\euskadi-large.png"
  Delete "$INSTDIR\data\flags\euskadi-shield-large.png"
  Delete "$INSTDIR\data\flags\euskadi-shield.png"
  Delete "$INSTDIR\data\flags\euskadi.png"
  Delete "$INSTDIR\data\flags\fiji-large.png"
  Delete "$INSTDIR\data\flags\fiji-shield-large.png"
  Delete "$INSTDIR\data\flags\fiji-shield.png"
  Delete "$INSTDIR\data\flags\fiji.png"
  Delete "$INSTDIR\data\flags\finland-large.png"
  Delete "$INSTDIR\data\flags\finland-shield-large.png"
  Delete "$INSTDIR\data\flags\finland-shield.png"
  Delete "$INSTDIR\data\flags\finland.png"
  Delete "$INSTDIR\data\flags\flanders-large.png"
  Delete "$INSTDIR\data\flags\flanders-shield-large.png"
  Delete "$INSTDIR\data\flags\flanders-shield.png"
  Delete "$INSTDIR\data\flags\flanders.png"
  Delete "$INSTDIR\data\flags\france-large.png"
  Delete "$INSTDIR\data\flags\france-shield-large.png"
  Delete "$INSTDIR\data\flags\france-shield.png"
  Delete "$INSTDIR\data\flags\france.png"
  Delete "$INSTDIR\data\flags\france_old-large.png"
  Delete "$INSTDIR\data\flags\france_old-shield-large.png"
  Delete "$INSTDIR\data\flags\france_old-shield.png"
  Delete "$INSTDIR\data\flags\france_old.png"
  Delete "$INSTDIR\data\flags\franconia-large.png"
  Delete "$INSTDIR\data\flags\franconia-shield-large.png"
  Delete "$INSTDIR\data\flags\franconia-shield.png"
  Delete "$INSTDIR\data\flags\franconia.png"
  Delete "$INSTDIR\data\flags\frisia-large.png"
  Delete "$INSTDIR\data\flags\frisia-shield-large.png"
  Delete "$INSTDIR\data\flags\frisia-shield.png"
  Delete "$INSTDIR\data\flags\frisia.png"
  Delete "$INSTDIR\data\flags\gael-large.png"
  Delete "$INSTDIR\data\flags\gael-shield-large.png"
  Delete "$INSTDIR\data\flags\gael-shield.png"
  Delete "$INSTDIR\data\flags\gael.png"
  Delete "$INSTDIR\data\flags\galicia-large.png"
  Delete "$INSTDIR\data\flags\galicia-shield-large.png"
  Delete "$INSTDIR\data\flags\galicia-shield.png"
  Delete "$INSTDIR\data\flags\galicia.png"
  Delete "$INSTDIR\data\flags\gaul-large.png"
  Delete "$INSTDIR\data\flags\gaul-shield-large.png"
  Delete "$INSTDIR\data\flags\gaul-shield.png"
  Delete "$INSTDIR\data\flags\gaul.png"
  Delete "$INSTDIR\data\flags\georgia-large.png"
  Delete "$INSTDIR\data\flags\georgia-shield-large.png"
  Delete "$INSTDIR\data\flags\georgia-shield.png"
  Delete "$INSTDIR\data\flags\georgia.png"
  Delete "$INSTDIR\data\flags\germany-large.png"
  Delete "$INSTDIR\data\flags\germany-shield-large.png"
  Delete "$INSTDIR\data\flags\germany-shield.png"
  Delete "$INSTDIR\data\flags\germany.png"
  Delete "$INSTDIR\data\flags\ghana-large.png"
  Delete "$INSTDIR\data\flags\ghana-shield-large.png"
  Delete "$INSTDIR\data\flags\ghana-shield.png"
  Delete "$INSTDIR\data\flags\ghana.png"
  Delete "$INSTDIR\data\flags\gokturk-large.png"
  Delete "$INSTDIR\data\flags\gokturk-shield-large.png"
  Delete "$INSTDIR\data\flags\gokturk-shield.png"
  Delete "$INSTDIR\data\flags\gokturk.png"
  Delete "$INSTDIR\data\flags\greater_poland-large.png"
  Delete "$INSTDIR\data\flags\greater_poland-shield-large.png"
  Delete "$INSTDIR\data\flags\greater_poland-shield.png"
  Delete "$INSTDIR\data\flags\greater_poland.png"
  Delete "$INSTDIR\data\flags\greece-large.png"
  Delete "$INSTDIR\data\flags\greece-shield-large.png"
  Delete "$INSTDIR\data\flags\greece-shield.png"
  Delete "$INSTDIR\data\flags\greece.png"
  Delete "$INSTDIR\data\flags\greece_ancient-large.png"
  Delete "$INSTDIR\data\flags\greece_ancient-shield-large.png"
  Delete "$INSTDIR\data\flags\greece_ancient-shield.png"
  Delete "$INSTDIR\data\flags\greece_ancient.png"
  Delete "$INSTDIR\data\flags\greenland-large.png"
  Delete "$INSTDIR\data\flags\greenland-shield-large.png"
  Delete "$INSTDIR\data\flags\greenland-shield.png"
  Delete "$INSTDIR\data\flags\greenland.png"
  Delete "$INSTDIR\data\flags\grenada-large.png"
  Delete "$INSTDIR\data\flags\grenada-shield-large.png"
  Delete "$INSTDIR\data\flags\grenada-shield.png"
  Delete "$INSTDIR\data\flags\grenada.png"
  Delete "$INSTDIR\data\flags\guanche-large.png"
  Delete "$INSTDIR\data\flags\guanche-shield-large.png"
  Delete "$INSTDIR\data\flags\guanche-shield.png"
  Delete "$INSTDIR\data\flags\guanche.png"
  Delete "$INSTDIR\data\flags\guarani-large.png"
  Delete "$INSTDIR\data\flags\guarani-shield-large.png"
  Delete "$INSTDIR\data\flags\guarani-shield.png"
  Delete "$INSTDIR\data\flags\guarani.png"
  Delete "$INSTDIR\data\flags\guatemala-large.png"
  Delete "$INSTDIR\data\flags\guatemala-shield-large.png"
  Delete "$INSTDIR\data\flags\guatemala-shield.png"
  Delete "$INSTDIR\data\flags\guatemala.png"
  Delete "$INSTDIR\data\flags\gupta-large.png"
  Delete "$INSTDIR\data\flags\gupta-shield-large.png"
  Delete "$INSTDIR\data\flags\gupta-shield.png"
  Delete "$INSTDIR\data\flags\gupta.png"
  Delete "$INSTDIR\data\flags\guyana-large.png"
  Delete "$INSTDIR\data\flags\guyana-shield-large.png"
  Delete "$INSTDIR\data\flags\guyana-shield.png"
  Delete "$INSTDIR\data\flags\guyana.png"
  Delete "$INSTDIR\data\flags\hacker-large.png"
  Delete "$INSTDIR\data\flags\hacker-shield-large.png"
  Delete "$INSTDIR\data\flags\hacker-shield.png"
  Delete "$INSTDIR\data\flags\hacker.png"
  Delete "$INSTDIR\data\flags\hainan-large.png"
  Delete "$INSTDIR\data\flags\hainan-shield-large.png"
  Delete "$INSTDIR\data\flags\hainan-shield.png"
  Delete "$INSTDIR\data\flags\hainan.png"
  Delete "$INSTDIR\data\flags\haiti-large.png"
  Delete "$INSTDIR\data\flags\haiti-shield-large.png"
  Delete "$INSTDIR\data\flags\haiti-shield.png"
  Delete "$INSTDIR\data\flags\haiti.png"
  Delete "$INSTDIR\data\flags\han-large.png"
  Delete "$INSTDIR\data\flags\han-shield-large.png"
  Delete "$INSTDIR\data\flags\han-shield.png"
  Delete "$INSTDIR\data\flags\han.png"
  Delete "$INSTDIR\data\flags\hanover-large.png"
  Delete "$INSTDIR\data\flags\hanover-shield-large.png"
  Delete "$INSTDIR\data\flags\hanover-shield.png"
  Delete "$INSTDIR\data\flags\hanover.png"
  Delete "$INSTDIR\data\flags\hansa-large.png"
  Delete "$INSTDIR\data\flags\hansa-shield-large.png"
  Delete "$INSTDIR\data\flags\hansa-shield.png"
  Delete "$INSTDIR\data\flags\hansa.png"
  Delete "$INSTDIR\data\flags\hawaii-large.png"
  Delete "$INSTDIR\data\flags\hawaii-shield-large.png"
  Delete "$INSTDIR\data\flags\hawaii-shield.png"
  Delete "$INSTDIR\data\flags\hawaii.png"
  Delete "$INSTDIR\data\flags\hesse-large.png"
  Delete "$INSTDIR\data\flags\hesse-shield-large.png"
  Delete "$INSTDIR\data\flags\hesse-shield.png"
  Delete "$INSTDIR\data\flags\hesse.png"
  Delete "$INSTDIR\data\flags\himyar-large.png"
  Delete "$INSTDIR\data\flags\himyar-shield-large.png"
  Delete "$INSTDIR\data\flags\himyar-shield.png"
  Delete "$INSTDIR\data\flags\himyar.png"
  Delete "$INSTDIR\data\flags\hittite-large.png"
  Delete "$INSTDIR\data\flags\hittite-shield-large.png"
  Delete "$INSTDIR\data\flags\hittite-shield.png"
  Delete "$INSTDIR\data\flags\hittite.png"
  Delete "$INSTDIR\data\flags\honduras-large.png"
  Delete "$INSTDIR\data\flags\honduras-shield-large.png"
  Delete "$INSTDIR\data\flags\honduras-shield.png"
  Delete "$INSTDIR\data\flags\honduras.png"
  Delete "$INSTDIR\data\flags\hopi-large.png"
  Delete "$INSTDIR\data\flags\hopi-shield-large.png"
  Delete "$INSTDIR\data\flags\hopi-shield.png"
  Delete "$INSTDIR\data\flags\hopi.png"
  Delete "$INSTDIR\data\flags\hre-large.png"
  Delete "$INSTDIR\data\flags\hre-shield-large.png"
  Delete "$INSTDIR\data\flags\hre-shield.png"
  Delete "$INSTDIR\data\flags\hre.png"
  Delete "$INSTDIR\data\flags\hungary-large.png"
  Delete "$INSTDIR\data\flags\hungary-shield-large.png"
  Delete "$INSTDIR\data\flags\hungary-shield.png"
  Delete "$INSTDIR\data\flags\hungary.png"
  Delete "$INSTDIR\data\flags\iberian-large.png"
  Delete "$INSTDIR\data\flags\iberian-shield-large.png"
  Delete "$INSTDIR\data\flags\iberian-shield.png"
  Delete "$INSTDIR\data\flags\iberian.png"
  Delete "$INSTDIR\data\flags\iceland-large.png"
  Delete "$INSTDIR\data\flags\iceland-shield-large.png"
  Delete "$INSTDIR\data\flags\iceland-shield.png"
  Delete "$INSTDIR\data\flags\iceland.png"
  Delete "$INSTDIR\data\flags\illyria-large.png"
  Delete "$INSTDIR\data\flags\illyria-shield-large.png"
  Delete "$INSTDIR\data\flags\illyria-shield.png"
  Delete "$INSTDIR\data\flags\illyria.png"
  Delete "$INSTDIR\data\flags\inca-large.png"
  Delete "$INSTDIR\data\flags\inca-shield-large.png"
  Delete "$INSTDIR\data\flags\inca-shield.png"
  Delete "$INSTDIR\data\flags\inca.png"
  Delete "$INSTDIR\data\flags\india-large.png"
  Delete "$INSTDIR\data\flags\india-shield-large.png"
  Delete "$INSTDIR\data\flags\india-shield.png"
  Delete "$INSTDIR\data\flags\india.png"
  Delete "$INSTDIR\data\flags\indonesia-large.png"
  Delete "$INSTDIR\data\flags\indonesia-shield-large.png"
  Delete "$INSTDIR\data\flags\indonesia-shield.png"
  Delete "$INSTDIR\data\flags\indonesia.png"
  Delete "$INSTDIR\data\flags\innu-large.png"
  Delete "$INSTDIR\data\flags\innu-shield-large.png"
  Delete "$INSTDIR\data\flags\innu-shield.png"
  Delete "$INSTDIR\data\flags\innu.png"
  Delete "$INSTDIR\data\flags\iran-large.png"
  Delete "$INSTDIR\data\flags\iran-shield-large.png"
  Delete "$INSTDIR\data\flags\iran-shield.png"
  Delete "$INSTDIR\data\flags\iran.png"
  Delete "$INSTDIR\data\flags\iran_ancient-large.png"
  Delete "$INSTDIR\data\flags\iran_ancient-shield-large.png"
  Delete "$INSTDIR\data\flags\iran_ancient-shield.png"
  Delete "$INSTDIR\data\flags\iran_ancient.png"
  Delete "$INSTDIR\data\flags\iraq-large.png"
  Delete "$INSTDIR\data\flags\iraq-shield-large.png"
  Delete "$INSTDIR\data\flags\iraq-shield.png"
  Delete "$INSTDIR\data\flags\iraq.png"
  Delete "$INSTDIR\data\flags\iraq_old-large.png"
  Delete "$INSTDIR\data\flags\iraq_old-shield-large.png"
  Delete "$INSTDIR\data\flags\iraq_old-shield.png"
  Delete "$INSTDIR\data\flags\iraq_old.png"
  Delete "$INSTDIR\data\flags\ireland-large.png"
  Delete "$INSTDIR\data\flags\ireland-shield-large.png"
  Delete "$INSTDIR\data\flags\ireland-shield.png"
  Delete "$INSTDIR\data\flags\ireland.png"
  Delete "$INSTDIR\data\flags\iroquois-large.png"
  Delete "$INSTDIR\data\flags\iroquois-shield-large.png"
  Delete "$INSTDIR\data\flags\iroquois-shield.png"
  Delete "$INSTDIR\data\flags\iroquois.png"
  Delete "$INSTDIR\data\flags\israel-large.png"
  Delete "$INSTDIR\data\flags\israel-shield-large.png"
  Delete "$INSTDIR\data\flags\israel-shield.png"
  Delete "$INSTDIR\data\flags\israel.png"
  Delete "$INSTDIR\data\flags\italy-large.png"
  Delete "$INSTDIR\data\flags\italy-shield-large.png"
  Delete "$INSTDIR\data\flags\italy-shield.png"
  Delete "$INSTDIR\data\flags\italy.png"
  Delete "$INSTDIR\data\flags\ivory_coast-large.png"
  Delete "$INSTDIR\data\flags\ivory_coast-shield-large.png"
  Delete "$INSTDIR\data\flags\ivory_coast-shield.png"
  Delete "$INSTDIR\data\flags\ivory_coast.png"
  Delete "$INSTDIR\data\flags\jamaica-large.png"
  Delete "$INSTDIR\data\flags\jamaica-shield-large.png"
  Delete "$INSTDIR\data\flags\jamaica-shield.png"
  Delete "$INSTDIR\data\flags\jamaica.png"
  Delete "$INSTDIR\data\flags\japan-large.png"
  Delete "$INSTDIR\data\flags\japan-shield-large.png"
  Delete "$INSTDIR\data\flags\japan-shield.png"
  Delete "$INSTDIR\data\flags\japan.png"
  Delete "$INSTDIR\data\flags\jbonai-large.png"
  Delete "$INSTDIR\data\flags\jbonai-shield-large.png"
  Delete "$INSTDIR\data\flags\jbonai-shield.png"
  Delete "$INSTDIR\data\flags\jbonai.png"
  Delete "$INSTDIR\data\flags\jolof-large.png"
  Delete "$INSTDIR\data\flags\jolof-shield-large.png"
  Delete "$INSTDIR\data\flags\jolof-shield.png"
  Delete "$INSTDIR\data\flags\jolof.png"
  Delete "$INSTDIR\data\flags\kalmykia-large.png"
  Delete "$INSTDIR\data\flags\kalmykia-shield-large.png"
  Delete "$INSTDIR\data\flags\kalmykia-shield.png"
  Delete "$INSTDIR\data\flags\kalmykia.png"
  Delete "$INSTDIR\data\flags\kampuchea-large.png"
  Delete "$INSTDIR\data\flags\kampuchea-shield-large.png"
  Delete "$INSTDIR\data\flags\kampuchea-shield.png"
  Delete "$INSTDIR\data\flags\kampuchea.png"
  Delete "$INSTDIR\data\flags\kanem-bornu-large.png"
  Delete "$INSTDIR\data\flags\kanem-bornu-shield-large.png"
  Delete "$INSTDIR\data\flags\kanem-bornu-shield.png"
  Delete "$INSTDIR\data\flags\kanem-bornu.png"
  Delete "$INSTDIR\data\flags\karelia-large.png"
  Delete "$INSTDIR\data\flags\karelia-shield-large.png"
  Delete "$INSTDIR\data\flags\karelia-shield.png"
  Delete "$INSTDIR\data\flags\karelia.png"
  Delete "$INSTDIR\data\flags\kashmir-large.png"
  Delete "$INSTDIR\data\flags\kashmir-shield-large.png"
  Delete "$INSTDIR\data\flags\kashmir-shield.png"
  Delete "$INSTDIR\data\flags\kashmir.png"
  Delete "$INSTDIR\data\flags\kazakhstan-large.png"
  Delete "$INSTDIR\data\flags\kazakhstan-shield-large.png"
  Delete "$INSTDIR\data\flags\kazakhstan-shield.png"
  Delete "$INSTDIR\data\flags\kazakhstan.png"
  Delete "$INSTDIR\data\flags\keetoowah-large.png"
  Delete "$INSTDIR\data\flags\keetoowah-shield-large.png"
  Delete "$INSTDIR\data\flags\keetoowah-shield.png"
  Delete "$INSTDIR\data\flags\keetoowah.png"
  Delete "$INSTDIR\data\flags\kenya-large.png"
  Delete "$INSTDIR\data\flags\kenya-shield-large.png"
  Delete "$INSTDIR\data\flags\kenya-shield.png"
  Delete "$INSTDIR\data\flags\kenya.png"
  Delete "$INSTDIR\data\flags\khazaria-large.png"
  Delete "$INSTDIR\data\flags\khazaria-shield-large.png"
  Delete "$INSTDIR\data\flags\khazaria-shield.png"
  Delete "$INSTDIR\data\flags\khazaria.png"
  Delete "$INSTDIR\data\flags\khwarezm-large.png"
  Delete "$INSTDIR\data\flags\khwarezm-shield-large.png"
  Delete "$INSTDIR\data\flags\khwarezm-shield.png"
  Delete "$INSTDIR\data\flags\khwarezm.png"
  Delete "$INSTDIR\data\flags\kiev-large.png"
  Delete "$INSTDIR\data\flags\kiev-shield-large.png"
  Delete "$INSTDIR\data\flags\kiev-shield.png"
  Delete "$INSTDIR\data\flags\kiev.png"
  Delete "$INSTDIR\data\flags\kongo-large.png"
  Delete "$INSTDIR\data\flags\kongo-shield-large.png"
  Delete "$INSTDIR\data\flags\kongo-shield.png"
  Delete "$INSTDIR\data\flags\kongo.png"
  Delete "$INSTDIR\data\flags\korea-large.png"
  Delete "$INSTDIR\data\flags\korea-shield-large.png"
  Delete "$INSTDIR\data\flags\korea-shield.png"
  Delete "$INSTDIR\data\flags\korea.png"
  Delete "$INSTDIR\data\flags\korea_ancient-large.png"
  Delete "$INSTDIR\data\flags\korea_ancient-shield-large.png"
  Delete "$INSTDIR\data\flags\korea_ancient-shield.png"
  Delete "$INSTDIR\data\flags\korea_ancient.png"
  Delete "$INSTDIR\data\flags\kosovo-large.png"
  Delete "$INSTDIR\data\flags\kosovo-shield-large.png"
  Delete "$INSTDIR\data\flags\kosovo-shield.png"
  Delete "$INSTDIR\data\flags\kosovo.png"
  Delete "$INSTDIR\data\flags\kurd-large.png"
  Delete "$INSTDIR\data\flags\kurd-shield-large.png"
  Delete "$INSTDIR\data\flags\kurd-shield.png"
  Delete "$INSTDIR\data\flags\kurd.png"
  Delete "$INSTDIR\data\flags\kyrgyzstan-large.png"
  Delete "$INSTDIR\data\flags\kyrgyzstan-shield-large.png"
  Delete "$INSTDIR\data\flags\kyrgyzstan-shield.png"
  Delete "$INSTDIR\data\flags\kyrgyzstan.png"
  Delete "$INSTDIR\data\flags\labarum-large.png"
  Delete "$INSTDIR\data\flags\labarum-shield-large.png"
  Delete "$INSTDIR\data\flags\labarum-shield.png"
  Delete "$INSTDIR\data\flags\labarum.png"
  Delete "$INSTDIR\data\flags\laos-large.png"
  Delete "$INSTDIR\data\flags\laos-shield-large.png"
  Delete "$INSTDIR\data\flags\laos-shield.png"
  Delete "$INSTDIR\data\flags\laos.png"
  Delete "$INSTDIR\data\flags\latvia-large.png"
  Delete "$INSTDIR\data\flags\latvia-shield-large.png"
  Delete "$INSTDIR\data\flags\latvia-shield.png"
  Delete "$INSTDIR\data\flags\latvia.png"
  Delete "$INSTDIR\data\flags\lebanon-large.png"
  Delete "$INSTDIR\data\flags\lebanon-shield-large.png"
  Delete "$INSTDIR\data\flags\lebanon-shield.png"
  Delete "$INSTDIR\data\flags\lebanon.png"
  Delete "$INSTDIR\data\flags\lendian-large.png"
  Delete "$INSTDIR\data\flags\lendian-shield-large.png"
  Delete "$INSTDIR\data\flags\lendian-shield.png"
  Delete "$INSTDIR\data\flags\lendian.png"
  Delete "$INSTDIR\data\flags\leon-large.png"
  Delete "$INSTDIR\data\flags\leon-shield-large.png"
  Delete "$INSTDIR\data\flags\leon-shield.png"
  Delete "$INSTDIR\data\flags\leon.png"
  Delete "$INSTDIR\data\flags\libya-large.png"
  Delete "$INSTDIR\data\flags\libya-shield-large.png"
  Delete "$INSTDIR\data\flags\libya-shield.png"
  Delete "$INSTDIR\data\flags\libya.png"
  Delete "$INSTDIR\data\flags\liechtenstein-large.png"
  Delete "$INSTDIR\data\flags\liechtenstein-shield-large.png"
  Delete "$INSTDIR\data\flags\liechtenstein-shield.png"
  Delete "$INSTDIR\data\flags\liechtenstein.png"
  Delete "$INSTDIR\data\flags\lipkatatar-large.png"
  Delete "$INSTDIR\data\flags\lipkatatar-shield-large.png"
  Delete "$INSTDIR\data\flags\lipkatatar-shield.png"
  Delete "$INSTDIR\data\flags\lipkatatar.png"
  Delete "$INSTDIR\data\flags\lithuania-large.png"
  Delete "$INSTDIR\data\flags\lithuania-shield-large.png"
  Delete "$INSTDIR\data\flags\lithuania-shield.png"
  Delete "$INSTDIR\data\flags\lithuania.png"
  Delete "$INSTDIR\data\flags\lorraine-large.png"
  Delete "$INSTDIR\data\flags\lorraine-shield-large.png"
  Delete "$INSTDIR\data\flags\lorraine-shield.png"
  Delete "$INSTDIR\data\flags\lorraine.png"
  Delete "$INSTDIR\data\flags\lusatia-large.png"
  Delete "$INSTDIR\data\flags\lusatia-shield-large.png"
  Delete "$INSTDIR\data\flags\lusatia-shield.png"
  Delete "$INSTDIR\data\flags\lusatia.png"
  Delete "$INSTDIR\data\flags\luxembourg-large.png"
  Delete "$INSTDIR\data\flags\luxembourg-shield-large.png"
  Delete "$INSTDIR\data\flags\luxembourg-shield.png"
  Delete "$INSTDIR\data\flags\luxembourg.png"
  Delete "$INSTDIR\data\flags\maasai-large.png"
  Delete "$INSTDIR\data\flags\maasai-shield-large.png"
  Delete "$INSTDIR\data\flags\maasai-shield.png"
  Delete "$INSTDIR\data\flags\maasai.png"
  Delete "$INSTDIR\data\flags\macedon-large.png"
  Delete "$INSTDIR\data\flags\macedon-shield-large.png"
  Delete "$INSTDIR\data\flags\macedon-shield.png"
  Delete "$INSTDIR\data\flags\macedon.png"
  Delete "$INSTDIR\data\flags\macedonia-large.png"
  Delete "$INSTDIR\data\flags\macedonia-shield-large.png"
  Delete "$INSTDIR\data\flags\macedonia-shield.png"
  Delete "$INSTDIR\data\flags\macedonia.png"
  Delete "$INSTDIR\data\flags\madagascar-large.png"
  Delete "$INSTDIR\data\flags\madagascar-shield-large.png"
  Delete "$INSTDIR\data\flags\madagascar-shield.png"
  Delete "$INSTDIR\data\flags\madagascar.png"
  Delete "$INSTDIR\data\flags\majapahit-large.png"
  Delete "$INSTDIR\data\flags\majapahit-shield-large.png"
  Delete "$INSTDIR\data\flags\majapahit-shield.png"
  Delete "$INSTDIR\data\flags\majapahit.png"
  Delete "$INSTDIR\data\flags\malawi-large.png"
  Delete "$INSTDIR\data\flags\malawi-shield-large.png"
  Delete "$INSTDIR\data\flags\malawi-shield.png"
  Delete "$INSTDIR\data\flags\malawi.png"
  Delete "$INSTDIR\data\flags\malaysia-large.png"
  Delete "$INSTDIR\data\flags\malaysia-shield-large.png"
  Delete "$INSTDIR\data\flags\malaysia-shield.png"
  Delete "$INSTDIR\data\flags\malaysia.png"
  Delete "$INSTDIR\data\flags\mali-large.png"
  Delete "$INSTDIR\data\flags\mali-shield-large.png"
  Delete "$INSTDIR\data\flags\mali-shield.png"
  Delete "$INSTDIR\data\flags\mali.png"
  Delete "$INSTDIR\data\flags\mali_ancient-large.png"
  Delete "$INSTDIR\data\flags\mali_ancient-shield-large.png"
  Delete "$INSTDIR\data\flags\mali_ancient-shield.png"
  Delete "$INSTDIR\data\flags\mali_ancient.png"
  Delete "$INSTDIR\data\flags\malta-large.png"
  Delete "$INSTDIR\data\flags\malta-shield-large.png"
  Delete "$INSTDIR\data\flags\malta-shield.png"
  Delete "$INSTDIR\data\flags\malta.png"
  Delete "$INSTDIR\data\flags\man-large.png"
  Delete "$INSTDIR\data\flags\man-shield-large.png"
  Delete "$INSTDIR\data\flags\man-shield.png"
  Delete "$INSTDIR\data\flags\man.png"
  Delete "$INSTDIR\data\flags\manchuria-large.png"
  Delete "$INSTDIR\data\flags\manchuria-shield-large.png"
  Delete "$INSTDIR\data\flags\manchuria-shield.png"
  Delete "$INSTDIR\data\flags\manchuria.png"
  Delete "$INSTDIR\data\flags\maori-large.png"
  Delete "$INSTDIR\data\flags\maori-shield-large.png"
  Delete "$INSTDIR\data\flags\maori-shield.png"
  Delete "$INSTDIR\data\flags\maori.png"
  Delete "$INSTDIR\data\flags\mapuche-large.png"
  Delete "$INSTDIR\data\flags\mapuche-shield-large.png"
  Delete "$INSTDIR\data\flags\mapuche-shield.png"
  Delete "$INSTDIR\data\flags\mapuche.png"
  Delete "$INSTDIR\data\flags\mars-large.png"
  Delete "$INSTDIR\data\flags\mars-shield-large.png"
  Delete "$INSTDIR\data\flags\mars-shield.png"
  Delete "$INSTDIR\data\flags\mars.png"
  Delete "$INSTDIR\data\flags\maya-large.png"
  Delete "$INSTDIR\data\flags\maya-shield-large.png"
  Delete "$INSTDIR\data\flags\maya-shield.png"
  Delete "$INSTDIR\data\flags\maya.png"
  Delete "$INSTDIR\data\flags\mazovia-large.png"
  Delete "$INSTDIR\data\flags\mazovia-shield-large.png"
  Delete "$INSTDIR\data\flags\mazovia-shield.png"
  Delete "$INSTDIR\data\flags\mazovia.png"
  Delete "$INSTDIR\data\flags\mecklenburg-large.png"
  Delete "$INSTDIR\data\flags\mecklenburg-shield-large.png"
  Delete "$INSTDIR\data\flags\mecklenburg-shield.png"
  Delete "$INSTDIR\data\flags\mecklenburg.png"
  Delete "$INSTDIR\data\flags\metis-large.png"
  Delete "$INSTDIR\data\flags\metis-shield-large.png"
  Delete "$INSTDIR\data\flags\metis-shield.png"
  Delete "$INSTDIR\data\flags\metis.png"
  Delete "$INSTDIR\data\flags\mexico-large.png"
  Delete "$INSTDIR\data\flags\mexico-shield-large.png"
  Delete "$INSTDIR\data\flags\mexico-shield.png"
  Delete "$INSTDIR\data\flags\mexico.png"
  Delete "$INSTDIR\data\flags\micronesia-large.png"
  Delete "$INSTDIR\data\flags\micronesia-shield-large.png"
  Delete "$INSTDIR\data\flags\micronesia-shield.png"
  Delete "$INSTDIR\data\flags\micronesia.png"
  Delete "$INSTDIR\data\flags\mikmaq-large.png"
  Delete "$INSTDIR\data\flags\mikmaq-shield-large.png"
  Delete "$INSTDIR\data\flags\mikmaq-shield.png"
  Delete "$INSTDIR\data\flags\mikmaq.png"
  Delete "$INSTDIR\data\flags\milan-large.png"
  Delete "$INSTDIR\data\flags\milan-shield-large.png"
  Delete "$INSTDIR\data\flags\milan-shield.png"
  Delete "$INSTDIR\data\flags\milan.png"
  Delete "$INSTDIR\data\flags\miskito-large.png"
  Delete "$INSTDIR\data\flags\miskito-shield-large.png"
  Delete "$INSTDIR\data\flags\miskito-shield.png"
  Delete "$INSTDIR\data\flags\miskito.png"
  Delete "$INSTDIR\data\flags\mixtec-large.png"
  Delete "$INSTDIR\data\flags\mixtec-shield-large.png"
  Delete "$INSTDIR\data\flags\mixtec-shield.png"
  Delete "$INSTDIR\data\flags\mixtec.png"
  Delete "$INSTDIR\data\flags\moldova-large.png"
  Delete "$INSTDIR\data\flags\moldova-shield-large.png"
  Delete "$INSTDIR\data\flags\moldova-shield.png"
  Delete "$INSTDIR\data\flags\moldova.png"
  Delete "$INSTDIR\data\flags\monaco_alternative-large.png"
  Delete "$INSTDIR\data\flags\monaco_alternative-shield-large.png"
  Delete "$INSTDIR\data\flags\monaco_alternative-shield.png"
  Delete "$INSTDIR\data\flags\monaco_alternative.png"
  Delete "$INSTDIR\data\flags\mongolia-large.png"
  Delete "$INSTDIR\data\flags\mongolia-shield-large.png"
  Delete "$INSTDIR\data\flags\mongolia-shield.png"
  Delete "$INSTDIR\data\flags\mongolia.png"
  Delete "$INSTDIR\data\flags\montenegro-large.png"
  Delete "$INSTDIR\data\flags\montenegro-shield-large.png"
  Delete "$INSTDIR\data\flags\montenegro-shield.png"
  Delete "$INSTDIR\data\flags\montenegro.png"
  Delete "$INSTDIR\data\flags\moravia-large.png"
  Delete "$INSTDIR\data\flags\moravia-shield-large.png"
  Delete "$INSTDIR\data\flags\moravia-shield.png"
  Delete "$INSTDIR\data\flags\moravia.png"
  Delete "$INSTDIR\data\flags\mordovia-large.png"
  Delete "$INSTDIR\data\flags\mordovia-shield-large.png"
  Delete "$INSTDIR\data\flags\mordovia-shield.png"
  Delete "$INSTDIR\data\flags\mordovia.png"
  Delete "$INSTDIR\data\flags\morocco-large.png"
  Delete "$INSTDIR\data\flags\morocco-shield-large.png"
  Delete "$INSTDIR\data\flags\morocco-shield.png"
  Delete "$INSTDIR\data\flags\morocco.png"
  Delete "$INSTDIR\data\flags\mozambique-large.png"
  Delete "$INSTDIR\data\flags\mozambique-shield-large.png"
  Delete "$INSTDIR\data\flags\mozambique-shield.png"
  Delete "$INSTDIR\data\flags\mozambique.png"
  Delete "$INSTDIR\data\flags\mughal-large.png"
  Delete "$INSTDIR\data\flags\mughal-shield-large.png"
  Delete "$INSTDIR\data\flags\mughal-shield.png"
  Delete "$INSTDIR\data\flags\mughal.png"
  Delete "$INSTDIR\data\flags\muskogee-large.png"
  Delete "$INSTDIR\data\flags\muskogee-shield-large.png"
  Delete "$INSTDIR\data\flags\muskogee-shield.png"
  Delete "$INSTDIR\data\flags\muskogee.png"
  Delete "$INSTDIR\data\flags\mwiska-large.png"
  Delete "$INSTDIR\data\flags\mwiska-shield-large.png"
  Delete "$INSTDIR\data\flags\mwiska-shield.png"
  Delete "$INSTDIR\data\flags\mwiska.png"
  Delete "$INSTDIR\data\flags\myanmar-large.png"
  Delete "$INSTDIR\data\flags\myanmar-shield-large.png"
  Delete "$INSTDIR\data\flags\myanmar-shield.png"
  Delete "$INSTDIR\data\flags\myanmar.png"
  Delete "$INSTDIR\data\flags\namibia-large.png"
  Delete "$INSTDIR\data\flags\namibia-shield-large.png"
  Delete "$INSTDIR\data\flags\namibia-shield.png"
  Delete "$INSTDIR\data\flags\namibia.png"
  Delete "$INSTDIR\data\flags\naples-large.png"
  Delete "$INSTDIR\data\flags\naples-shield-large.png"
  Delete "$INSTDIR\data\flags\naples-shield.png"
  Delete "$INSTDIR\data\flags\naples.png"
  Delete "$INSTDIR\data\flags\nato-large.png"
  Delete "$INSTDIR\data\flags\nato-shield-large.png"
  Delete "$INSTDIR\data\flags\nato-shield.png"
  Delete "$INSTDIR\data\flags\nato.png"
  Delete "$INSTDIR\data\flags\navajo-large.png"
  Delete "$INSTDIR\data\flags\navajo-shield-large.png"
  Delete "$INSTDIR\data\flags\navajo-shield.png"
  Delete "$INSTDIR\data\flags\navajo.png"
  Delete "$INSTDIR\data\flags\nepal-large.png"
  Delete "$INSTDIR\data\flags\nepal-shield-large.png"
  Delete "$INSTDIR\data\flags\nepal-shield.png"
  Delete "$INSTDIR\data\flags\nepal.png"
  Delete "$INSTDIR\data\flags\nestoria-large.png"
  Delete "$INSTDIR\data\flags\nestoria-shield-large.png"
  Delete "$INSTDIR\data\flags\nestoria-shield.png"
  Delete "$INSTDIR\data\flags\nestoria.png"
  Delete "$INSTDIR\data\flags\netherlands-large.png"
  Delete "$INSTDIR\data\flags\netherlands-shield-large.png"
  Delete "$INSTDIR\data\flags\netherlands-shield.png"
  Delete "$INSTDIR\data\flags\netherlands.png"
  Delete "$INSTDIR\data\flags\newfoundland-large.png"
  Delete "$INSTDIR\data\flags\newfoundland-shield-large.png"
  Delete "$INSTDIR\data\flags\newfoundland-shield.png"
  Delete "$INSTDIR\data\flags\newfoundland.png"
  Delete "$INSTDIR\data\flags\newzealand-large.png"
  Delete "$INSTDIR\data\flags\newzealand-shield-large.png"
  Delete "$INSTDIR\data\flags\newzealand-shield.png"
  Delete "$INSTDIR\data\flags\newzealand.png"
  Delete "$INSTDIR\data\flags\nez_perce-large.png"
  Delete "$INSTDIR\data\flags\nez_perce-shield-large.png"
  Delete "$INSTDIR\data\flags\nez_perce-shield.png"
  Delete "$INSTDIR\data\flags\nez_perce.png"
  Delete "$INSTDIR\data\flags\nicaragua-large.png"
  Delete "$INSTDIR\data\flags\nicaragua-shield-large.png"
  Delete "$INSTDIR\data\flags\nicaragua-shield.png"
  Delete "$INSTDIR\data\flags\nicaragua.png"
  Delete "$INSTDIR\data\flags\niger-large.png"
  Delete "$INSTDIR\data\flags\niger-shield-large.png"
  Delete "$INSTDIR\data\flags\niger-shield.png"
  Delete "$INSTDIR\data\flags\niger.png"
  Delete "$INSTDIR\data\flags\nigeria-large.png"
  Delete "$INSTDIR\data\flags\nigeria-shield-large.png"
  Delete "$INSTDIR\data\flags\nigeria-shield.png"
  Delete "$INSTDIR\data\flags\nigeria.png"
  Delete "$INSTDIR\data\flags\normandy-large.png"
  Delete "$INSTDIR\data\flags\normandy-shield-large.png"
  Delete "$INSTDIR\data\flags\normandy-shield.png"
  Delete "$INSTDIR\data\flags\normandy.png"
  Delete "$INSTDIR\data\flags\northumbria-large.png"
  Delete "$INSTDIR\data\flags\northumbria-shield-large.png"
  Delete "$INSTDIR\data\flags\northumbria-shield.png"
  Delete "$INSTDIR\data\flags\northumbria.png"
  Delete "$INSTDIR\data\flags\north_korea-large.png"
  Delete "$INSTDIR\data\flags\north_korea-shield-large.png"
  Delete "$INSTDIR\data\flags\north_korea-shield.png"
  Delete "$INSTDIR\data\flags\north_korea.png"
  Delete "$INSTDIR\data\flags\norway-large.png"
  Delete "$INSTDIR\data\flags\norway-shield-large.png"
  Delete "$INSTDIR\data\flags\norway-shield.png"
  Delete "$INSTDIR\data\flags\norway.png"
  Delete "$INSTDIR\data\flags\nubia-large.png"
  Delete "$INSTDIR\data\flags\nubia-shield-large.png"
  Delete "$INSTDIR\data\flags\nubia-shield.png"
  Delete "$INSTDIR\data\flags\nubia.png"
  Delete "$INSTDIR\data\flags\numidia-large.png"
  Delete "$INSTDIR\data\flags\numidia-shield-large.png"
  Delete "$INSTDIR\data\flags\numidia-shield.png"
  Delete "$INSTDIR\data\flags\numidia.png"
  Delete "$INSTDIR\data\flags\nunavut-large.png"
  Delete "$INSTDIR\data\flags\nunavut-shield-large.png"
  Delete "$INSTDIR\data\flags\nunavut-shield.png"
  Delete "$INSTDIR\data\flags\nunavut.png"
  Delete "$INSTDIR\data\flags\nuu-chah-nulth-large.png"
  Delete "$INSTDIR\data\flags\nuu-chah-nulth-shield-large.png"
  Delete "$INSTDIR\data\flags\nuu-chah-nulth-shield.png"
  Delete "$INSTDIR\data\flags\nuu-chah-nulth.png"
  Delete "$INSTDIR\data\flags\occitania-large.png"
  Delete "$INSTDIR\data\flags\occitania-shield-large.png"
  Delete "$INSTDIR\data\flags\occitania-shield.png"
  Delete "$INSTDIR\data\flags\occitania.png"
  Delete "$INSTDIR\data\flags\ohlone-large.png"
  Delete "$INSTDIR\data\flags\ohlone-shield-large.png"
  Delete "$INSTDIR\data\flags\ohlone-shield.png"
  Delete "$INSTDIR\data\flags\ohlone.png"
  Delete "$INSTDIR\data\flags\oldenburg-large.png"
  Delete "$INSTDIR\data\flags\oldenburg-shield-large.png"
  Delete "$INSTDIR\data\flags\oldenburg-shield.png"
  Delete "$INSTDIR\data\flags\oldenburg.png"
  Delete "$INSTDIR\data\flags\oman-large.png"
  Delete "$INSTDIR\data\flags\oman-shield-large.png"
  Delete "$INSTDIR\data\flags\oman-shield.png"
  Delete "$INSTDIR\data\flags\oman.png"
  Delete "$INSTDIR\data\flags\ossetia-large.png"
  Delete "$INSTDIR\data\flags\ossetia-shield-large.png"
  Delete "$INSTDIR\data\flags\ossetia-shield.png"
  Delete "$INSTDIR\data\flags\ossetia.png"
  Delete "$INSTDIR\data\flags\otomi-large.png"
  Delete "$INSTDIR\data\flags\otomi-shield-large.png"
  Delete "$INSTDIR\data\flags\otomi-shield.png"
  Delete "$INSTDIR\data\flags\otomi.png"
  Delete "$INSTDIR\data\flags\ottoman-large.png"
  Delete "$INSTDIR\data\flags\ottoman-shield-large.png"
  Delete "$INSTDIR\data\flags\ottoman-shield.png"
  Delete "$INSTDIR\data\flags\ottoman.png"
  Delete "$INSTDIR\data\flags\oz-large.png"
  Delete "$INSTDIR\data\flags\oz-shield-large.png"
  Delete "$INSTDIR\data\flags\oz-shield.png"
  Delete "$INSTDIR\data\flags\oz.png"
  Delete "$INSTDIR\data\flags\pakistan-large.png"
  Delete "$INSTDIR\data\flags\pakistan-shield-large.png"
  Delete "$INSTDIR\data\flags\pakistan-shield.png"
  Delete "$INSTDIR\data\flags\pakistan.png"
  Delete "$INSTDIR\data\flags\palatinate-large.png"
  Delete "$INSTDIR\data\flags\palatinate-shield-large.png"
  Delete "$INSTDIR\data\flags\palatinate-shield.png"
  Delete "$INSTDIR\data\flags\palatinate.png"
  Delete "$INSTDIR\data\flags\palestine-large.png"
  Delete "$INSTDIR\data\flags\palestine-shield-large.png"
  Delete "$INSTDIR\data\flags\palestine-shield.png"
  Delete "$INSTDIR\data\flags\palestine.png"
  Delete "$INSTDIR\data\flags\palmyra-large.png"
  Delete "$INSTDIR\data\flags\palmyra-shield-large.png"
  Delete "$INSTDIR\data\flags\palmyra-shield.png"
  Delete "$INSTDIR\data\flags\palmyra.png"
  Delete "$INSTDIR\data\flags\panama-large.png"
  Delete "$INSTDIR\data\flags\panama-shield-large.png"
  Delete "$INSTDIR\data\flags\panama-shield.png"
  Delete "$INSTDIR\data\flags\panama.png"
  Delete "$INSTDIR\data\flags\papua_newguinea-large.png"
  Delete "$INSTDIR\data\flags\papua_newguinea-shield-large.png"
  Delete "$INSTDIR\data\flags\papua_newguinea-shield.png"
  Delete "$INSTDIR\data\flags\papua_newguinea.png"
  Delete "$INSTDIR\data\flags\paraguay-large.png"
  Delete "$INSTDIR\data\flags\paraguay-shield-large.png"
  Delete "$INSTDIR\data\flags\paraguay-shield.png"
  Delete "$INSTDIR\data\flags\paraguay.png"
  Delete "$INSTDIR\data\flags\pashtun-large.png"
  Delete "$INSTDIR\data\flags\pashtun-shield-large.png"
  Delete "$INSTDIR\data\flags\pashtun-shield.png"
  Delete "$INSTDIR\data\flags\pashtun.png"
  Delete "$INSTDIR\data\flags\peru-large.png"
  Delete "$INSTDIR\data\flags\peru-shield-large.png"
  Delete "$INSTDIR\data\flags\peru-shield.png"
  Delete "$INSTDIR\data\flags\peru.png"
  Delete "$INSTDIR\data\flags\philippines-large.png"
  Delete "$INSTDIR\data\flags\philippines-shield-large.png"
  Delete "$INSTDIR\data\flags\philippines-shield.png"
  Delete "$INSTDIR\data\flags\philippines.png"
  Delete "$INSTDIR\data\flags\phoenicia-large.png"
  Delete "$INSTDIR\data\flags\phoenicia-shield-large.png"
  Delete "$INSTDIR\data\flags\phoenicia-shield.png"
  Delete "$INSTDIR\data\flags\phoenicia.png"
  Delete "$INSTDIR\data\flags\piedmont-large.png"
  Delete "$INSTDIR\data\flags\piedmont-shield-large.png"
  Delete "$INSTDIR\data\flags\piedmont-shield.png"
  Delete "$INSTDIR\data\flags\piedmont.png"
  Delete "$INSTDIR\data\flags\pirate-large.png"
  Delete "$INSTDIR\data\flags\pirate-shield-large.png"
  Delete "$INSTDIR\data\flags\pirate-shield.png"
  Delete "$INSTDIR\data\flags\pirate.png"
  Delete "$INSTDIR\data\flags\piratini-large.png"
  Delete "$INSTDIR\data\flags\piratini-shield-large.png"
  Delete "$INSTDIR\data\flags\piratini-shield.png"
  Delete "$INSTDIR\data\flags\piratini.png"
  Delete "$INSTDIR\data\flags\poland-large.png"
  Delete "$INSTDIR\data\flags\poland-shield-large.png"
  Delete "$INSTDIR\data\flags\poland-shield.png"
  Delete "$INSTDIR\data\flags\poland.png"
  Delete "$INSTDIR\data\flags\polynesian-large.png"
  Delete "$INSTDIR\data\flags\polynesian-shield-large.png"
  Delete "$INSTDIR\data\flags\polynesian-shield.png"
  Delete "$INSTDIR\data\flags\polynesian.png"
  Delete "$INSTDIR\data\flags\pomerania-large.png"
  Delete "$INSTDIR\data\flags\pomerania-shield-large.png"
  Delete "$INSTDIR\data\flags\pomerania-shield.png"
  Delete "$INSTDIR\data\flags\pomerania.png"
  Delete "$INSTDIR\data\flags\portugal-large.png"
  Delete "$INSTDIR\data\flags\portugal-shield-large.png"
  Delete "$INSTDIR\data\flags\portugal-shield.png"
  Delete "$INSTDIR\data\flags\portugal.png"
  Delete "$INSTDIR\data\flags\prussia-large.png"
  Delete "$INSTDIR\data\flags\prussia-shield-large.png"
  Delete "$INSTDIR\data\flags\prussia-shield.png"
  Delete "$INSTDIR\data\flags\prussia.png"
  Delete "$INSTDIR\data\flags\puerto_rico-large.png"
  Delete "$INSTDIR\data\flags\puerto_rico-shield-large.png"
  Delete "$INSTDIR\data\flags\puerto_rico-shield.png"
  Delete "$INSTDIR\data\flags\puerto_rico.png"
  Delete "$INSTDIR\data\flags\purhepecha-large.png"
  Delete "$INSTDIR\data\flags\purhepecha-shield-large.png"
  Delete "$INSTDIR\data\flags\purhepecha-shield.png"
  Delete "$INSTDIR\data\flags\purhepecha.png"
  Delete "$INSTDIR\data\flags\qing-large.png"
  Delete "$INSTDIR\data\flags\qing-shield-large.png"
  Delete "$INSTDIR\data\flags\qing-shield.png"
  Delete "$INSTDIR\data\flags\qing.png"
  Delete "$INSTDIR\data\flags\quebec-large.png"
  Delete "$INSTDIR\data\flags\quebec-shield-large.png"
  Delete "$INSTDIR\data\flags\quebec-shield.png"
  Delete "$INSTDIR\data\flags\quebec.png"
  Delete "$INSTDIR\data\flags\raramuri-large.png"
  Delete "$INSTDIR\data\flags\raramuri-shield-large.png"
  Delete "$INSTDIR\data\flags\raramuri-shield.png"
  Delete "$INSTDIR\data\flags\raramuri.png"
  Delete "$INSTDIR\data\flags\rif-large.png"
  Delete "$INSTDIR\data\flags\rif-shield-large.png"
  Delete "$INSTDIR\data\flags\rif-shield.png"
  Delete "$INSTDIR\data\flags\rif.png"
  Delete "$INSTDIR\data\flags\romania-large.png"
  Delete "$INSTDIR\data\flags\romania-shield-large.png"
  Delete "$INSTDIR\data\flags\romania-shield.png"
  Delete "$INSTDIR\data\flags\romania.png"
  Delete "$INSTDIR\data\flags\rome-large.png"
  Delete "$INSTDIR\data\flags\rome-shield-large.png"
  Delete "$INSTDIR\data\flags\rome-shield.png"
  Delete "$INSTDIR\data\flags\rome.png"
  Delete "$INSTDIR\data\flags\russia-large.png"
  Delete "$INSTDIR\data\flags\russia-shield-large.png"
  Delete "$INSTDIR\data\flags\russia-shield.png"
  Delete "$INSTDIR\data\flags\russia.png"
  Delete "$INSTDIR\data\flags\rvn-large.png"
  Delete "$INSTDIR\data\flags\rvn-shield-large.png"
  Delete "$INSTDIR\data\flags\rvn-shield.png"
  Delete "$INSTDIR\data\flags\rvn.png"
  Delete "$INSTDIR\data\flags\rwanda-large.png"
  Delete "$INSTDIR\data\flags\rwanda-shield-large.png"
  Delete "$INSTDIR\data\flags\rwanda-shield.png"
  Delete "$INSTDIR\data\flags\rwanda.png"
  Delete "$INSTDIR\data\flags\ryukyu-large.png"
  Delete "$INSTDIR\data\flags\ryukyu-shield-large.png"
  Delete "$INSTDIR\data\flags\ryukyu-shield.png"
  Delete "$INSTDIR\data\flags\ryukyu.png"
  Delete "$INSTDIR\data\flags\sadr-large.png"
  Delete "$INSTDIR\data\flags\sadr-shield-large.png"
  Delete "$INSTDIR\data\flags\sadr-shield.png"
  Delete "$INSTDIR\data\flags\sadr.png"
  Delete "$INSTDIR\data\flags\sakha-large.png"
  Delete "$INSTDIR\data\flags\sakha-shield-large.png"
  Delete "$INSTDIR\data\flags\sakha-shield.png"
  Delete "$INSTDIR\data\flags\sakha.png"
  Delete "$INSTDIR\data\flags\samogitia-large.png"
  Delete "$INSTDIR\data\flags\samogitia-shield-large.png"
  Delete "$INSTDIR\data\flags\samogitia-shield.png"
  Delete "$INSTDIR\data\flags\samogitia.png"
  Delete "$INSTDIR\data\flags\san_marino-large.png"
  Delete "$INSTDIR\data\flags\san_marino-shield-large.png"
  Delete "$INSTDIR\data\flags\san_marino-shield.png"
  Delete "$INSTDIR\data\flags\san_marino.png"
  Delete "$INSTDIR\data\flags\sapmi-large.png"
  Delete "$INSTDIR\data\flags\sapmi-shield-large.png"
  Delete "$INSTDIR\data\flags\sapmi-shield.png"
  Delete "$INSTDIR\data\flags\sapmi.png"
  Delete "$INSTDIR\data\flags\sarmatia-large.png"
  Delete "$INSTDIR\data\flags\sarmatia-shield-large.png"
  Delete "$INSTDIR\data\flags\sarmatia-shield.png"
  Delete "$INSTDIR\data\flags\sarmatia.png"
  Delete "$INSTDIR\data\flags\saudi_arabia-large.png"
  Delete "$INSTDIR\data\flags\saudi_arabia-shield-large.png"
  Delete "$INSTDIR\data\flags\saudi_arabia-shield.png"
  Delete "$INSTDIR\data\flags\saudi_arabia.png"
  Delete "$INSTDIR\data\flags\savoy-large.png"
  Delete "$INSTDIR\data\flags\savoy-shield-large.png"
  Delete "$INSTDIR\data\flags\savoy-shield.png"
  Delete "$INSTDIR\data\flags\savoy.png"
  Delete "$INSTDIR\data\flags\saxony-large.png"
  Delete "$INSTDIR\data\flags\saxony-shield-large.png"
  Delete "$INSTDIR\data\flags\saxony-shield.png"
  Delete "$INSTDIR\data\flags\saxony.png"
  Delete "$INSTDIR\data\flags\schleswig-holstein-large.png"
  Delete "$INSTDIR\data\flags\schleswig-holstein-shield-large.png"
  Delete "$INSTDIR\data\flags\schleswig-holstein-shield.png"
  Delete "$INSTDIR\data\flags\schleswig-holstein.png"
  Delete "$INSTDIR\data\flags\scotland-large.png"
  Delete "$INSTDIR\data\flags\scotland-shield-large.png"
  Delete "$INSTDIR\data\flags\scotland-shield.png"
  Delete "$INSTDIR\data\flags\scotland.png"
  Delete "$INSTDIR\data\flags\scythia-large.png"
  Delete "$INSTDIR\data\flags\scythia-shield-large.png"
  Delete "$INSTDIR\data\flags\scythia-shield.png"
  Delete "$INSTDIR\data\flags\scythia.png"
  Delete "$INSTDIR\data\flags\seleucid-large.png"
  Delete "$INSTDIR\data\flags\seleucid-shield-large.png"
  Delete "$INSTDIR\data\flags\seleucid-shield.png"
  Delete "$INSTDIR\data\flags\seleucid.png"
  Delete "$INSTDIR\data\flags\senegal-large.png"
  Delete "$INSTDIR\data\flags\senegal-shield-large.png"
  Delete "$INSTDIR\data\flags\senegal-shield.png"
  Delete "$INSTDIR\data\flags\senegal.png"
  Delete "$INSTDIR\data\flags\serbia-large.png"
  Delete "$INSTDIR\data\flags\serbia-shield-large.png"
  Delete "$INSTDIR\data\flags\serbia-shield.png"
  Delete "$INSTDIR\data\flags\serbia.png"
  Delete "$INSTDIR\data\flags\shawnee-large.png"
  Delete "$INSTDIR\data\flags\shawnee-shield-large.png"
  Delete "$INSTDIR\data\flags\shawnee-shield.png"
  Delete "$INSTDIR\data\flags\shawnee.png"
  Delete "$INSTDIR\data\flags\siberia-large.png"
  Delete "$INSTDIR\data\flags\siberia-shield-large.png"
  Delete "$INSTDIR\data\flags\siberia-shield.png"
  Delete "$INSTDIR\data\flags\siberia.png"
  Delete "$INSTDIR\data\flags\sicily-large.png"
  Delete "$INSTDIR\data\flags\sicily-shield-large.png"
  Delete "$INSTDIR\data\flags\sicily-shield.png"
  Delete "$INSTDIR\data\flags\sicily.png"
  Delete "$INSTDIR\data\flags\sikh-large.png"
  Delete "$INSTDIR\data\flags\sikh-shield-large.png"
  Delete "$INSTDIR\data\flags\sikh-shield.png"
  Delete "$INSTDIR\data\flags\sikh.png"
  Delete "$INSTDIR\data\flags\sikkim-large.png"
  Delete "$INSTDIR\data\flags\sikkim-shield-large.png"
  Delete "$INSTDIR\data\flags\sikkim-shield.png"
  Delete "$INSTDIR\data\flags\sikkim.png"
  Delete "$INSTDIR\data\flags\silesia-large.png"
  Delete "$INSTDIR\data\flags\silesia-shield-large.png"
  Delete "$INSTDIR\data\flags\silesia-shield.png"
  Delete "$INSTDIR\data\flags\silesia.png"
  Delete "$INSTDIR\data\flags\singapore-large.png"
  Delete "$INSTDIR\data\flags\singapore-shield-large.png"
  Delete "$INSTDIR\data\flags\singapore-shield.png"
  Delete "$INSTDIR\data\flags\singapore.png"
  Delete "$INSTDIR\data\flags\slavic-large.png"
  Delete "$INSTDIR\data\flags\slavic-shield-large.png"
  Delete "$INSTDIR\data\flags\slavic-shield.png"
  Delete "$INSTDIR\data\flags\slavic.png"
  Delete "$INSTDIR\data\flags\slovakia-large.png"
  Delete "$INSTDIR\data\flags\slovakia-shield-large.png"
  Delete "$INSTDIR\data\flags\slovakia-shield.png"
  Delete "$INSTDIR\data\flags\slovakia.png"
  Delete "$INSTDIR\data\flags\slovenia-large.png"
  Delete "$INSTDIR\data\flags\slovenia-shield-large.png"
  Delete "$INSTDIR\data\flags\slovenia-shield.png"
  Delete "$INSTDIR\data\flags\slovenia.png"
  Delete "$INSTDIR\data\flags\somalia-large.png"
  Delete "$INSTDIR\data\flags\somalia-shield-large.png"
  Delete "$INSTDIR\data\flags\somalia-shield.png"
  Delete "$INSTDIR\data\flags\somalia.png"
  Delete "$INSTDIR\data\flags\songhai-large.png"
  Delete "$INSTDIR\data\flags\songhai-shield-large.png"
  Delete "$INSTDIR\data\flags\songhai-shield.png"
  Delete "$INSTDIR\data\flags\songhai.png"
  Delete "$INSTDIR\data\flags\southern_cross-large.png"
  Delete "$INSTDIR\data\flags\southern_cross-shield-large.png"
  Delete "$INSTDIR\data\flags\southern_cross-shield.png"
  Delete "$INSTDIR\data\flags\southern_cross.png"
  Delete "$INSTDIR\data\flags\south_africa-large.png"
  Delete "$INSTDIR\data\flags\south_africa-shield-large.png"
  Delete "$INSTDIR\data\flags\south_africa-shield.png"
  Delete "$INSTDIR\data\flags\south_africa.png"
  Delete "$INSTDIR\data\flags\south_yemen-large.png"
  Delete "$INSTDIR\data\flags\south_yemen-shield-large.png"
  Delete "$INSTDIR\data\flags\south_yemen-shield.png"
  Delete "$INSTDIR\data\flags\south_yemen.png"
  Delete "$INSTDIR\data\flags\soviet-large.png"
  Delete "$INSTDIR\data\flags\soviet-shield-large.png"
  Delete "$INSTDIR\data\flags\soviet-shield.png"
  Delete "$INSTDIR\data\flags\soviet.png"
  Delete "$INSTDIR\data\flags\spain-large.png"
  Delete "$INSTDIR\data\flags\spain-shield-large.png"
  Delete "$INSTDIR\data\flags\spain-shield.png"
  Delete "$INSTDIR\data\flags\spain.png"
  Delete "$INSTDIR\data\flags\srilanka-large.png"
  Delete "$INSTDIR\data\flags\srilanka-shield-large.png"
  Delete "$INSTDIR\data\flags\srilanka-shield.png"
  Delete "$INSTDIR\data\flags\srilanka.png"
  Delete "$INSTDIR\data\flags\srivijaya-large.png"
  Delete "$INSTDIR\data\flags\srivijaya-shield-large.png"
  Delete "$INSTDIR\data\flags\srivijaya-shield.png"
  Delete "$INSTDIR\data\flags\srivijaya.png"
  Delete "$INSTDIR\data\flags\stpatrick-large.png"
  Delete "$INSTDIR\data\flags\stpatrick-shield-large.png"
  Delete "$INSTDIR\data\flags\stpatrick-shield.png"
  Delete "$INSTDIR\data\flags\stpatrick.png"
  Delete "$INSTDIR\data\flags\sudan-large.png"
  Delete "$INSTDIR\data\flags\sudan-shield-large.png"
  Delete "$INSTDIR\data\flags\sudan-shield.png"
  Delete "$INSTDIR\data\flags\sudan.png"
  Delete "$INSTDIR\data\flags\sumeria-large.png"
  Delete "$INSTDIR\data\flags\sumeria-shield-large.png"
  Delete "$INSTDIR\data\flags\sumeria-shield.png"
  Delete "$INSTDIR\data\flags\sumeria.png"
  Delete "$INSTDIR\data\flags\suriname-large.png"
  Delete "$INSTDIR\data\flags\suriname-shield-large.png"
  Delete "$INSTDIR\data\flags\suriname-shield.png"
  Delete "$INSTDIR\data\flags\suriname.png"
  Delete "$INSTDIR\data\flags\svg-large.png"
  Delete "$INSTDIR\data\flags\svg-shield-large.png"
  Delete "$INSTDIR\data\flags\svg-shield.png"
  Delete "$INSTDIR\data\flags\svg.png"
  Delete "$INSTDIR\data\flags\swaziland-large.png"
  Delete "$INSTDIR\data\flags\swaziland-shield-large.png"
  Delete "$INSTDIR\data\flags\swaziland-shield.png"
  Delete "$INSTDIR\data\flags\swaziland.png"
  Delete "$INSTDIR\data\flags\sweden-large.png"
  Delete "$INSTDIR\data\flags\sweden-shield-large.png"
  Delete "$INSTDIR\data\flags\sweden-shield.png"
  Delete "$INSTDIR\data\flags\sweden.png"
  Delete "$INSTDIR\data\flags\swiss-large.png"
  Delete "$INSTDIR\data\flags\swiss-shield-large.png"
  Delete "$INSTDIR\data\flags\swiss-shield.png"
  Delete "$INSTDIR\data\flags\swiss.png"
  Delete "$INSTDIR\data\flags\syria-large.png"
  Delete "$INSTDIR\data\flags\syria-shield-large.png"
  Delete "$INSTDIR\data\flags\syria-shield.png"
  Delete "$INSTDIR\data\flags\syria.png"
  Delete "$INSTDIR\data\flags\taino-large.png"
  Delete "$INSTDIR\data\flags\taino-shield-large.png"
  Delete "$INSTDIR\data\flags\taino-shield.png"
  Delete "$INSTDIR\data\flags\taino.png"
  Delete "$INSTDIR\data\flags\tairona-large.png"
  Delete "$INSTDIR\data\flags\tairona-shield-large.png"
  Delete "$INSTDIR\data\flags\tairona-shield.png"
  Delete "$INSTDIR\data\flags\tairona.png"
  Delete "$INSTDIR\data\flags\taiwan-large.png"
  Delete "$INSTDIR\data\flags\taiwan-shield-large.png"
  Delete "$INSTDIR\data\flags\taiwan-shield.png"
  Delete "$INSTDIR\data\flags\taiwan.png"
  Delete "$INSTDIR\data\flags\tajikistan-large.png"
  Delete "$INSTDIR\data\flags\tajikistan-shield-large.png"
  Delete "$INSTDIR\data\flags\tajikistan-shield.png"
  Delete "$INSTDIR\data\flags\tajikistan.png"
  Delete "$INSTDIR\data\flags\tannu_tuva-large.png"
  Delete "$INSTDIR\data\flags\tannu_tuva-shield-large.png"
  Delete "$INSTDIR\data\flags\tannu_tuva-shield.png"
  Delete "$INSTDIR\data\flags\tannu_tuva.png"
  Delete "$INSTDIR\data\flags\tanzania-large.png"
  Delete "$INSTDIR\data\flags\tanzania-shield-large.png"
  Delete "$INSTDIR\data\flags\tanzania-shield.png"
  Delete "$INSTDIR\data\flags\tanzania.png"
  Delete "$INSTDIR\data\flags\tatarstan-large.png"
  Delete "$INSTDIR\data\flags\tatarstan-shield-large.png"
  Delete "$INSTDIR\data\flags\tatarstan-shield.png"
  Delete "$INSTDIR\data\flags\tatarstan.png"
  Delete "$INSTDIR\data\flags\templar-large.png"
  Delete "$INSTDIR\data\flags\templar-shield-large.png"
  Delete "$INSTDIR\data\flags\templar-shield.png"
  Delete "$INSTDIR\data\flags\templar.png"
  Delete "$INSTDIR\data\flags\teutonic_order-large.png"
  Delete "$INSTDIR\data\flags\teutonic_order-shield-large.png"
  Delete "$INSTDIR\data\flags\teutonic_order-shield.png"
  Delete "$INSTDIR\data\flags\teutonic_order.png"
  Delete "$INSTDIR\data\flags\texas-large.png"
  Delete "$INSTDIR\data\flags\texas-shield-large.png"
  Delete "$INSTDIR\data\flags\texas-shield.png"
  Delete "$INSTDIR\data\flags\texas.png"
  Delete "$INSTDIR\data\flags\thailand-large.png"
  Delete "$INSTDIR\data\flags\thailand-shield-large.png"
  Delete "$INSTDIR\data\flags\thailand-shield.png"
  Delete "$INSTDIR\data\flags\thailand.png"
  Delete "$INSTDIR\data\flags\thrace-large.png"
  Delete "$INSTDIR\data\flags\thrace-shield-large.png"
  Delete "$INSTDIR\data\flags\thrace-shield.png"
  Delete "$INSTDIR\data\flags\thrace.png"
  Delete "$INSTDIR\data\flags\tibet-large.png"
  Delete "$INSTDIR\data\flags\tibet-shield-large.png"
  Delete "$INSTDIR\data\flags\tibet-shield.png"
  Delete "$INSTDIR\data\flags\tibet.png"
  Delete "$INSTDIR\data\flags\timur-large.png"
  Delete "$INSTDIR\data\flags\timur-shield-large.png"
  Delete "$INSTDIR\data\flags\timur-shield.png"
  Delete "$INSTDIR\data\flags\timur.png"
  Delete "$INSTDIR\data\flags\tocharian-large.png"
  Delete "$INSTDIR\data\flags\tocharian-shield-large.png"
  Delete "$INSTDIR\data\flags\tocharian-shield.png"
  Delete "$INSTDIR\data\flags\tocharian.png"
  Delete "$INSTDIR\data\flags\togo-large.png"
  Delete "$INSTDIR\data\flags\togo-shield-large.png"
  Delete "$INSTDIR\data\flags\togo-shield.png"
  Delete "$INSTDIR\data\flags\togo.png"
  Delete "$INSTDIR\data\flags\toltec-large.png"
  Delete "$INSTDIR\data\flags\toltec-shield-large.png"
  Delete "$INSTDIR\data\flags\toltec-shield.png"
  Delete "$INSTDIR\data\flags\toltec.png"
  Delete "$INSTDIR\data\flags\tonga-large.png"
  Delete "$INSTDIR\data\flags\tonga-shield-large.png"
  Delete "$INSTDIR\data\flags\tonga-shield.png"
  Delete "$INSTDIR\data\flags\tonga.png"
  Delete "$INSTDIR\data\flags\transylvania-large.png"
  Delete "$INSTDIR\data\flags\transylvania-shield-large.png"
  Delete "$INSTDIR\data\flags\transylvania-shield.png"
  Delete "$INSTDIR\data\flags\transylvania.png"
  Delete "$INSTDIR\data\flags\tunisia-large.png"
  Delete "$INSTDIR\data\flags\tunisia-shield-large.png"
  Delete "$INSTDIR\data\flags\tunisia-shield.png"
  Delete "$INSTDIR\data\flags\tunisia.png"
  Delete "$INSTDIR\data\flags\tupi-large.png"
  Delete "$INSTDIR\data\flags\tupi-shield-large.png"
  Delete "$INSTDIR\data\flags\tupi-shield.png"
  Delete "$INSTDIR\data\flags\tupi.png"
  Delete "$INSTDIR\data\flags\turkey-large.png"
  Delete "$INSTDIR\data\flags\turkey-shield-large.png"
  Delete "$INSTDIR\data\flags\turkey-shield.png"
  Delete "$INSTDIR\data\flags\turkey.png"
  Delete "$INSTDIR\data\flags\turkmenistan-large.png"
  Delete "$INSTDIR\data\flags\turkmenistan-shield-large.png"
  Delete "$INSTDIR\data\flags\turkmenistan-shield.png"
  Delete "$INSTDIR\data\flags\turkmenistan.png"
  Delete "$INSTDIR\data\flags\tyrol-large.png"
  Delete "$INSTDIR\data\flags\tyrol-shield-large.png"
  Delete "$INSTDIR\data\flags\tyrol-shield.png"
  Delete "$INSTDIR\data\flags\tyrol.png"
  Delete "$INSTDIR\data\flags\uae-large.png"
  Delete "$INSTDIR\data\flags\uae-shield-large.png"
  Delete "$INSTDIR\data\flags\uae-shield.png"
  Delete "$INSTDIR\data\flags\uae.png"
  Delete "$INSTDIR\data\flags\uganda-large.png"
  Delete "$INSTDIR\data\flags\uganda-shield-large.png"
  Delete "$INSTDIR\data\flags\uganda-shield.png"
  Delete "$INSTDIR\data\flags\uganda.png"
  Delete "$INSTDIR\data\flags\ukraine-large.png"
  Delete "$INSTDIR\data\flags\ukraine-shield-large.png"
  Delete "$INSTDIR\data\flags\ukraine-shield.png"
  Delete "$INSTDIR\data\flags\ukraine.png"
  Delete "$INSTDIR\data\flags\unasur-large.png"
  Delete "$INSTDIR\data\flags\unasur-shield-large.png"
  Delete "$INSTDIR\data\flags\unasur-shield.png"
  Delete "$INSTDIR\data\flags\unasur.png"
  Delete "$INSTDIR\data\flags\united_kingdom-large.png"
  Delete "$INSTDIR\data\flags\united_kingdom-shield-large.png"
  Delete "$INSTDIR\data\flags\united_kingdom-shield.png"
  Delete "$INSTDIR\data\flags\united_kingdom.png"
  Delete "$INSTDIR\data\flags\united_nations-large.png"
  Delete "$INSTDIR\data\flags\united_nations-shield-large.png"
  Delete "$INSTDIR\data\flags\united_nations-shield.png"
  Delete "$INSTDIR\data\flags\united_nations.png"
  Delete "$INSTDIR\data\flags\unknown-large.png"
  Delete "$INSTDIR\data\flags\unknown-shield-large.png"
  Delete "$INSTDIR\data\flags\unknown-shield.png"
  Delete "$INSTDIR\data\flags\unknown.png"
  Delete "$INSTDIR\data\flags\uruguay-large.png"
  Delete "$INSTDIR\data\flags\uruguay-shield-large.png"
  Delete "$INSTDIR\data\flags\uruguay-shield.png"
  Delete "$INSTDIR\data\flags\uruguay.png"
  Delete "$INSTDIR\data\flags\usa-large.png"
  Delete "$INSTDIR\data\flags\usa-shield-large.png"
  Delete "$INSTDIR\data\flags\usa-shield.png"
  Delete "$INSTDIR\data\flags\usa.png"
  Delete "$INSTDIR\data\flags\uyghur-large.png"
  Delete "$INSTDIR\data\flags\uyghur-shield-large.png"
  Delete "$INSTDIR\data\flags\uyghur-shield.png"
  Delete "$INSTDIR\data\flags\uyghur.png"
  Delete "$INSTDIR\data\flags\uzbekistan-large.png"
  Delete "$INSTDIR\data\flags\uzbekistan-shield-large.png"
  Delete "$INSTDIR\data\flags\uzbekistan-shield.png"
  Delete "$INSTDIR\data\flags\uzbekistan.png"
  Delete "$INSTDIR\data\flags\valknut-large.png"
  Delete "$INSTDIR\data\flags\valknut-shield-large.png"
  Delete "$INSTDIR\data\flags\valknut-shield.png"
  Delete "$INSTDIR\data\flags\valknut.png"
  Delete "$INSTDIR\data\flags\vampire-large.png"
  Delete "$INSTDIR\data\flags\vampire-shield-large.png"
  Delete "$INSTDIR\data\flags\vampire-shield.png"
  Delete "$INSTDIR\data\flags\vampire.png"
  Delete "$INSTDIR\data\flags\vandal-large.png"
  Delete "$INSTDIR\data\flags\vandal-shield-large.png"
  Delete "$INSTDIR\data\flags\vandal-shield.png"
  Delete "$INSTDIR\data\flags\vandal.png"
  Delete "$INSTDIR\data\flags\vatican-large.png"
  Delete "$INSTDIR\data\flags\vatican-shield-large.png"
  Delete "$INSTDIR\data\flags\vatican-shield.png"
  Delete "$INSTDIR\data\flags\vatican.png"
  Delete "$INSTDIR\data\flags\venezuela-large.png"
  Delete "$INSTDIR\data\flags\venezuela-shield-large.png"
  Delete "$INSTDIR\data\flags\venezuela-shield.png"
  Delete "$INSTDIR\data\flags\venezuela.png"
  Delete "$INSTDIR\data\flags\venice-large.png"
  Delete "$INSTDIR\data\flags\venice-shield-large.png"
  Delete "$INSTDIR\data\flags\venice-shield.png"
  Delete "$INSTDIR\data\flags\venice.png"
  Delete "$INSTDIR\data\flags\vermont-large.png"
  Delete "$INSTDIR\data\flags\vermont-shield-large.png"
  Delete "$INSTDIR\data\flags\vermont-shield.png"
  Delete "$INSTDIR\data\flags\vermont.png"
  Delete "$INSTDIR\data\flags\vietnam-large.png"
  Delete "$INSTDIR\data\flags\vietnam-shield-large.png"
  Delete "$INSTDIR\data\flags\vietnam-shield.png"
  Delete "$INSTDIR\data\flags\vietnam.png"
  Delete "$INSTDIR\data\flags\viking-large.png"
  Delete "$INSTDIR\data\flags\viking-shield-large.png"
  Delete "$INSTDIR\data\flags\viking-shield.png"
  Delete "$INSTDIR\data\flags\viking.png"
  Delete "$INSTDIR\data\flags\visigoth-large.png"
  Delete "$INSTDIR\data\flags\visigoth-shield-large.png"
  Delete "$INSTDIR\data\flags\visigoth-shield.png"
  Delete "$INSTDIR\data\flags\visigoth.png"
  Delete "$INSTDIR\data\flags\wales-large.png"
  Delete "$INSTDIR\data\flags\wales-shield-large.png"
  Delete "$INSTDIR\data\flags\wales-shield.png"
  Delete "$INSTDIR\data\flags\wales.png"
  Delete "$INSTDIR\data\flags\wallonia-large.png"
  Delete "$INSTDIR\data\flags\wallonia-shield-large.png"
  Delete "$INSTDIR\data\flags\wallonia-shield.png"
  Delete "$INSTDIR\data\flags\wallonia.png"
  Delete "$INSTDIR\data\flags\westphalia-large.png"
  Delete "$INSTDIR\data\flags\westphalia-shield-large.png"
  Delete "$INSTDIR\data\flags\westphalia-shield.png"
  Delete "$INSTDIR\data\flags\westphalia.png"
  Delete "$INSTDIR\data\flags\west_indies_federation-large.png"
  Delete "$INSTDIR\data\flags\west_indies_federation-shield-large.png"
  Delete "$INSTDIR\data\flags\west_indies_federation-shield.png"
  Delete "$INSTDIR\data\flags\west_indies_federation.png"
  Delete "$INSTDIR\data\flags\wuerttemberg-large.png"
  Delete "$INSTDIR\data\flags\wuerttemberg-shield-large.png"
  Delete "$INSTDIR\data\flags\wuerttemberg-shield.png"
  Delete "$INSTDIR\data\flags\wuerttemberg.png"
  Delete "$INSTDIR\data\flags\yemen-large.png"
  Delete "$INSTDIR\data\flags\yemen-shield-large.png"
  Delete "$INSTDIR\data\flags\yemen-shield.png"
  Delete "$INSTDIR\data\flags\yemen.png"
  Delete "$INSTDIR\data\flags\yucatan-large.png"
  Delete "$INSTDIR\data\flags\yucatan-shield-large.png"
  Delete "$INSTDIR\data\flags\yucatan-shield.png"
  Delete "$INSTDIR\data\flags\yucatan.png"
  Delete "$INSTDIR\data\flags\yugoslavia-large.png"
  Delete "$INSTDIR\data\flags\yugoslavia-shield-large.png"
  Delete "$INSTDIR\data\flags\yugoslavia-shield.png"
  Delete "$INSTDIR\data\flags\yugoslavia.png"
  Delete "$INSTDIR\data\flags\zapotec-large.png"
  Delete "$INSTDIR\data\flags\zapotec-shield-large.png"
  Delete "$INSTDIR\data\flags\zapotec-shield.png"
  Delete "$INSTDIR\data\flags\zapotec.png"
  Delete "$INSTDIR\data\flags\zimbabwe-large.png"
  Delete "$INSTDIR\data\flags\zimbabwe-shield-large.png"
  Delete "$INSTDIR\data\flags\zimbabwe-shield.png"
  Delete "$INSTDIR\data\flags\zimbabwe.png"
  Delete "$INSTDIR\data\flags\zulu-large.png"
  Delete "$INSTDIR\data\flags\zulu-shield-large.png"
  Delete "$INSTDIR\data\flags\zulu-shield.png"
  Delete "$INSTDIR\data\flags\zulu.png"
  Delete "$INSTDIR\data\freeciv.rc-2.0"
  Delete "$INSTDIR\data\gtk_menus.xml"
  Delete "$INSTDIR\data\helpdata.txt"
  Delete "$INSTDIR\data\hex2t\grid.png"
  Delete "$INSTDIR\data\hex2t\grid.spec"
  Delete "$INSTDIR\data\hex2t\items.png"
  Delete "$INSTDIR\data\hex2t\items.spec"
  Delete "$INSTDIR\data\hex2t\overlays.png"
  Delete "$INSTDIR\data\hex2t\overlays.spec"
  Delete "$INSTDIR\data\hex2t\select.png"
  Delete "$INSTDIR\data\hex2t\select.spec"
  Delete "$INSTDIR\data\hex2t\tiles.png"
  Delete "$INSTDIR\data\hex2t\tiles.spec"
  Delete "$INSTDIR\data\hex2t.tilespec"
  Delete "$INSTDIR\data\isophex\darkness.png"
  Delete "$INSTDIR\data\isophex\darkness.spec"
  Delete "$INSTDIR\data\isophex\gold.spec"
  Delete "$INSTDIR\data\isophex\grid.png"
  Delete "$INSTDIR\data\isophex\grid.spec"
  Delete "$INSTDIR\data\isophex\rivers.png"
  Delete "$INSTDIR\data\isophex\rivers.spec"
  Delete "$INSTDIR\data\isophex\terrain1.png"
  Delete "$INSTDIR\data\isophex\terrain1.spec"
  Delete "$INSTDIR\data\isophex\terrain2.png"
  Delete "$INSTDIR\data\isophex\terrain2.spec"
  Delete "$INSTDIR\data\isophex\tiles.png"
  Delete "$INSTDIR\data\isophex\tiles.spec"
  Delete "$INSTDIR\data\isophex.tilespec"
  Delete "$INSTDIR\data\isotrident\cities.png"
  Delete "$INSTDIR\data\isotrident\cities.spec"
  Delete "$INSTDIR\data\isotrident\fog.png"
  Delete "$INSTDIR\data\isotrident\fog.spec"
  Delete "$INSTDIR\data\isotrident\grid.png"
  Delete "$INSTDIR\data\isotrident\grid.spec"
  Delete "$INSTDIR\data\isotrident\morecities.png"
  Delete "$INSTDIR\data\isotrident\morecities.spec"
  Delete "$INSTDIR\data\isotrident\nuke.png"
  Delete "$INSTDIR\data\isotrident\nuke.spec"
  Delete "$INSTDIR\data\isotrident\select.png"
  Delete "$INSTDIR\data\isotrident\select.spec"
  Delete "$INSTDIR\data\isotrident\terrain1.png"
  Delete "$INSTDIR\data\isotrident\terrain1.spec"
  Delete "$INSTDIR\data\isotrident\terrain2.png"
  Delete "$INSTDIR\data\isotrident\terrain2.spec"
  Delete "$INSTDIR\data\isotrident\tiles.png"
  Delete "$INSTDIR\data\isotrident\tiles.spec"
  Delete "$INSTDIR\data\isotrident\unitextras.png"
  Delete "$INSTDIR\data\isotrident\unitextras.spec"
  Delete "$INSTDIR\data\isotrident.tilespec"
  Delete "$INSTDIR\data\misc\buildings-large.spec"
  Delete "$INSTDIR\data\misc\buildings.png"
  Delete "$INSTDIR\data\misc\buildings.spec"
  Delete "$INSTDIR\data\misc\chiefs.png"
  Delete "$INSTDIR\data\misc\chiefs.spec"
  Delete "$INSTDIR\data\misc\citybar.png"
  Delete "$INSTDIR\data\misc\citybar.spec"
  Delete "$INSTDIR\data\misc\cityicon.png"
  Delete "$INSTDIR\data\misc\civicon.png"
  Delete "$INSTDIR\data\misc\colors.png"
  Delete "$INSTDIR\data\misc\colors.spec"
  Delete "$INSTDIR\data\misc\colors.tilespec"
  Delete "$INSTDIR\data\misc\cursors.png"
  Delete "$INSTDIR\data\misc\cursors.spec"
  Delete "$INSTDIR\data\misc\editor.png"
  Delete "$INSTDIR\data\misc\editor.spec"
  Delete "$INSTDIR\data\misc\flags-large.spec"
  Delete "$INSTDIR\data\misc\flags.spec"
  Delete "$INSTDIR\data\misc\icons.spec"
  Delete "$INSTDIR\data\misc\intro.png"
  Delete "$INSTDIR\data\misc\overlays.png"
  Delete "$INSTDIR\data\misc\overlays.spec"
  Delete "$INSTDIR\data\misc\radar.png"
  Delete "$INSTDIR\data\misc\shields-large.spec"
  Delete "$INSTDIR\data\misc\shields.spec"
  Delete "$INSTDIR\data\misc\small.png"
  Delete "$INSTDIR\data\misc\small.spec"
  Delete "$INSTDIR\data\misc\space.png"
  Delete "$INSTDIR\data\misc\space.spec"
  Delete "$INSTDIR\data\misc\techs.png"
  Delete "$INSTDIR\data\misc\techs.spec"
  Delete "$INSTDIR\data\misc\treaty.png"
  Delete "$INSTDIR\data\misc\treaty.spec"
  Delete "$INSTDIR\data\misc\wonders-large.spec"
  Delete "$INSTDIR\data\multiplayer\ai_effects.ruleset"
  Delete "$INSTDIR\data\multiplayer\buildings.ruleset"
  Delete "$INSTDIR\data\multiplayer\cities.ruleset"
  Delete "$INSTDIR\data\multiplayer\default.lua"
  Delete "$INSTDIR\data\multiplayer\effects.ruleset"
  Delete "$INSTDIR\data\multiplayer\game.ruleset"
  Delete "$INSTDIR\data\multiplayer\governments.ruleset"
  Delete "$INSTDIR\data\multiplayer\script.lua"
  Delete "$INSTDIR\data\multiplayer\techs.ruleset"
  Delete "$INSTDIR\data\multiplayer\terrain.ruleset"
  Delete "$INSTDIR\data\multiplayer\units.ruleset"
  Delete "$INSTDIR\data\multiplayer.serv"
  Delete "$INSTDIR\data\nation\abkhaz.ruleset"
  Delete "$INSTDIR\data\nation\aborigines.ruleset"
  Delete "$INSTDIR\data\nation\acadian.ruleset"
  Delete "$INSTDIR\data\nation\acehnese.ruleset"
  Delete "$INSTDIR\data\nation\afghani.ruleset"
  Delete "$INSTDIR\data\nation\ainu.ruleset"
  Delete "$INSTDIR\data\nation\akwe.ruleset"
  Delete "$INSTDIR\data\nation\alandalus.ruleset"
  Delete "$INSTDIR\data\nation\albanian.ruleset"
  Delete "$INSTDIR\data\nation\aleut.ruleset"
  Delete "$INSTDIR\data\nation\algerian.ruleset"
  Delete "$INSTDIR\data\nation\amazigh.ruleset"
  Delete "$INSTDIR\data\nation\amazonian.ruleset"
  Delete "$INSTDIR\data\nation\american.ruleset"
  Delete "$INSTDIR\data\nation\andorran.ruleset"
  Delete "$INSTDIR\data\nation\angolan.ruleset"
  Delete "$INSTDIR\data\nation\anishinaabe.ruleset"
  Delete "$INSTDIR\data\nation\antarctican.ruleset"
  Delete "$INSTDIR\data\nation\apache.ruleset"
  Delete "$INSTDIR\data\nation\arab.ruleset"
  Delete "$INSTDIR\data\nation\aragonese.ruleset"
  Delete "$INSTDIR\data\nation\aramean.ruleset"
  Delete "$INSTDIR\data\nation\argentine.ruleset"
  Delete "$INSTDIR\data\nation\armenian.ruleset"
  Delete "$INSTDIR\data\nation\ashanti.ruleset"
  Delete "$INSTDIR\data\nation\assyrian.ruleset"
  Delete "$INSTDIR\data\nation\asturian.ruleset"
  Delete "$INSTDIR\data\nation\atlantean.ruleset"
  Delete "$INSTDIR\data\nation\australian.ruleset"
  Delete "$INSTDIR\data\nation\austrian.ruleset"
  Delete "$INSTDIR\data\nation\aymara.ruleset"
  Delete "$INSTDIR\data\nation\azeri.ruleset"
  Delete "$INSTDIR\data\nation\aztec.ruleset"
  Delete "$INSTDIR\data\nation\babylonian.ruleset"
  Delete "$INSTDIR\data\nation\badian.ruleset"
  Delete "$INSTDIR\data\nation\barbarian.ruleset"
  Delete "$INSTDIR\data\nation\bashkir.ruleset"
  Delete "$INSTDIR\data\nation\basque.ruleset"
  Delete "$INSTDIR\data\nation\bavarian.ruleset"
  Delete "$INSTDIR\data\nation\belarusian.ruleset"
  Delete "$INSTDIR\data\nation\belgian.ruleset"
  Delete "$INSTDIR\data\nation\bengali.ruleset"
  Delete "$INSTDIR\data\nation\benin.ruleset"
  Delete "$INSTDIR\data\nation\bhutanese.ruleset"
  Delete "$INSTDIR\data\nation\biafran.ruleset"
  Delete "$INSTDIR\data\nation\boer.ruleset"
  Delete "$INSTDIR\data\nation\bolivian.ruleset"
  Delete "$INSTDIR\data\nation\bosnia.ruleset"
  Delete "$INSTDIR\data\nation\bosporan.ruleset"
  Delete "$INSTDIR\data\nation\brandenburgian.ruleset"
  Delete "$INSTDIR\data\nation\brazilian.ruleset"
  Delete "$INSTDIR\data\nation\breton.ruleset"
  Delete "$INSTDIR\data\nation\british.ruleset"
  Delete "$INSTDIR\data\nation\briton.ruleset"
  Delete "$INSTDIR\data\nation\bulgarian.ruleset"
  Delete "$INSTDIR\data\nation\burgundian.ruleset"
  Delete "$INSTDIR\data\nation\burkinabe.ruleset"
  Delete "$INSTDIR\data\nation\burmese.ruleset"
  Delete "$INSTDIR\data\nation\burundi.ruleset"
  Delete "$INSTDIR\data\nation\byzantium.ruleset"
  Delete "$INSTDIR\data\nation\californian.ruleset"
  Delete "$INSTDIR\data\nation\cambodian.ruleset"
  Delete "$INSTDIR\data\nation\cameroonian.ruleset"
  Delete "$INSTDIR\data\nation\canadian.ruleset"
  Delete "$INSTDIR\data\nation\carthaginian.ruleset"
  Delete "$INSTDIR\data\nation\castilian.ruleset"
  Delete "$INSTDIR\data\nation\catalan.ruleset"
  Delete "$INSTDIR\data\nation\celtiberian.ruleset"
  Delete "$INSTDIR\data\nation\centralafrican.ruleset"
  Delete "$INSTDIR\data\nation\centralamerican.ruleset"
  Delete "$INSTDIR\data\nation\cham.ruleset"
  Delete "$INSTDIR\data\nation\chananean.ruleset"
  Delete "$INSTDIR\data\nation\chechen.ruleset"
  Delete "$INSTDIR\data\nation\cherokee.ruleset"
  Delete "$INSTDIR\data\nation\chilean.ruleset"
  Delete "$INSTDIR\data\nation\chimu.ruleset"
  Delete "$INSTDIR\data\nation\chinese.ruleset"
  Delete "$INSTDIR\data\nation\chola.ruleset"
  Delete "$INSTDIR\data\nation\chumash.ruleset"
  Delete "$INSTDIR\data\nation\colombian.ruleset"
  Delete "$INSTDIR\data\nation\comanche.ruleset"
  Delete "$INSTDIR\data\nation\confederate.ruleset"
  Delete "$INSTDIR\data\nation\congolese.ruleset"
  Delete "$INSTDIR\data\nation\cornish.ruleset"
  Delete "$INSTDIR\data\nation\corsican.ruleset"
  Delete "$INSTDIR\data\nation\cossack.ruleset"
  Delete "$INSTDIR\data\nation\costarican.ruleset"
  Delete "$INSTDIR\data\nation\cree.ruleset"
  Delete "$INSTDIR\data\nation\crimeantatar.ruleset"
  Delete "$INSTDIR\data\nation\croatian.ruleset"
  Delete "$INSTDIR\data\nation\cuban.ruleset"
  Delete "$INSTDIR\data\nation\curonian.ruleset"
  Delete "$INSTDIR\data\nation\cypriot.ruleset"
  Delete "$INSTDIR\data\nation\czech.ruleset"
  Delete "$INSTDIR\data\nation\dahomean.ruleset"
  Delete "$INSTDIR\data\nation\danish.ruleset"
  Delete "$INSTDIR\data\nation\dominican.ruleset"
  Delete "$INSTDIR\data\nation\dominicano.ruleset"
  Delete "$INSTDIR\data\nation\dryad.ruleset"
  Delete "$INSTDIR\data\nation\dutch.ruleset"
  Delete "$INSTDIR\data\nation\eastgerman.ruleset"
  Delete "$INSTDIR\data\nation\easttimorese.ruleset"
  Delete "$INSTDIR\data\nation\ecuadorian.ruleset"
  Delete "$INSTDIR\data\nation\egyptian.ruleset"
  Delete "$INSTDIR\data\nation\egyptianarab.ruleset"
  Delete "$INSTDIR\data\nation\elamite.ruleset"
  Delete "$INSTDIR\data\nation\emirati.ruleset"
  Delete "$INSTDIR\data\nation\english.ruleset"
  Delete "$INSTDIR\data\nation\eritrean.ruleset"
  Delete "$INSTDIR\data\nation\esperant.ruleset"
  Delete "$INSTDIR\data\nation\estonian.ruleset"
  Delete "$INSTDIR\data\nation\ethiopian.ruleset"
  Delete "$INSTDIR\data\nation\etruscan.ruleset"
  Delete "$INSTDIR\data\nation\european.ruleset"
  Delete "$INSTDIR\data\nation\fijian.ruleset"
  Delete "$INSTDIR\data\nation\filipino.ruleset"
  Delete "$INSTDIR\data\nation\finnish.ruleset"
  Delete "$INSTDIR\data\nation\flemish.ruleset"
  Delete "$INSTDIR\data\nation\franconian.ruleset"
  Delete "$INSTDIR\data\nation\french.ruleset"
  Delete "$INSTDIR\data\nation\frisian.ruleset"
  Delete "$INSTDIR\data\nation\gaelic.ruleset"
  Delete "$INSTDIR\data\nation\galician.ruleset"
  Delete "$INSTDIR\data\nation\gallic.ruleset"
  Delete "$INSTDIR\data\nation\georgian.ruleset"
  Delete "$INSTDIR\data\nation\german.ruleset"
  Delete "$INSTDIR\data\nation\ghanaian.ruleset"
  Delete "$INSTDIR\data\nation\gokturk.ruleset"
  Delete "$INSTDIR\data\nation\greaterpolish.ruleset"
  Delete "$INSTDIR\data\nation\greek.ruleset"
  Delete "$INSTDIR\data\nation\greenlander.ruleset"
  Delete "$INSTDIR\data\nation\grenadian.ruleset"
  Delete "$INSTDIR\data\nation\guanche.ruleset"
  Delete "$INSTDIR\data\nation\guarani.ruleset"
  Delete "$INSTDIR\data\nation\guatemalan.ruleset"
  Delete "$INSTDIR\data\nation\gupta.ruleset"
  Delete "$INSTDIR\data\nation\guyanese.ruleset"
  Delete "$INSTDIR\data\nation\hacker.ruleset"
  Delete "$INSTDIR\data\nation\haitian.ruleset"
  Delete "$INSTDIR\data\nation\han.ruleset"
  Delete "$INSTDIR\data\nation\hanoverian.ruleset"
  Delete "$INSTDIR\data\nation\hansa.ruleset"
  Delete "$INSTDIR\data\nation\hasinay.ruleset"
  Delete "$INSTDIR\data\nation\hawaiian.ruleset"
  Delete "$INSTDIR\data\nation\hellenic.ruleset"
  Delete "$INSTDIR\data\nation\hessian.ruleset"
  Delete "$INSTDIR\data\nation\himyarite.ruleset"
  Delete "$INSTDIR\data\nation\hittite.ruleset"
  Delete "$INSTDIR\data\nation\holyroman.ruleset"
  Delete "$INSTDIR\data\nation\holysee.ruleset"
  Delete "$INSTDIR\data\nation\honduran.ruleset"
  Delete "$INSTDIR\data\nation\hopi.ruleset"
  Delete "$INSTDIR\data\nation\hungarian.ruleset"
  Delete "$INSTDIR\data\nation\iberian.ruleset"
  Delete "$INSTDIR\data\nation\icelandic.ruleset"
  Delete "$INSTDIR\data\nation\illyrian.ruleset"
  Delete "$INSTDIR\data\nation\inca.ruleset"
  Delete "$INSTDIR\data\nation\indian.ruleset"
  Delete "$INSTDIR\data\nation\indonesian.ruleset"
  Delete "$INSTDIR\data\nation\inuit.ruleset"
  Delete "$INSTDIR\data\nation\iranian.ruleset"
  Delete "$INSTDIR\data\nation\iraqi.ruleset"
  Delete "$INSTDIR\data\nation\irish.ruleset"
  Delete "$INSTDIR\data\nation\iroquois.ruleset"
  Delete "$INSTDIR\data\nation\israeli.ruleset"
  Delete "$INSTDIR\data\nation\italian.ruleset"
  Delete "$INSTDIR\data\nation\ivoirian.ruleset"
  Delete "$INSTDIR\data\nation\jamaican.ruleset"
  Delete "$INSTDIR\data\nation\japanese.ruleset"
  Delete "$INSTDIR\data\nation\jolof.ruleset"
  Delete "$INSTDIR\data\nation\kalmyk.ruleset"
  Delete "$INSTDIR\data\nation\kanem-bornu.ruleset"
  Delete "$INSTDIR\data\nation\karelian.ruleset"
  Delete "$INSTDIR\data\nation\kashmiri.ruleset"
  Delete "$INSTDIR\data\nation\kazakh.ruleset"
  Delete "$INSTDIR\data\nation\kenyan.ruleset"
  Delete "$INSTDIR\data\nation\khazar.ruleset"
  Delete "$INSTDIR\data\nation\khwarezmian.ruleset"
  Delete "$INSTDIR\data\nation\kongo.ruleset"
  Delete "$INSTDIR\data\nation\korean.ruleset"
  Delete "$INSTDIR\data\nation\kosovar.ruleset"
  Delete "$INSTDIR\data\nation\kurd.ruleset"
  Delete "$INSTDIR\data\nation\kyrgyz.ruleset"
  Delete "$INSTDIR\data\nation\lankese.ruleset"
  Delete "$INSTDIR\data\nation\laotian.ruleset"
  Delete "$INSTDIR\data\nation\latvian.ruleset"
  Delete "$INSTDIR\data\nation\lebanese.ruleset"
  Delete "$INSTDIR\data\nation\lendian.ruleset"
  Delete "$INSTDIR\data\nation\leonese.ruleset"
  Delete "$INSTDIR\data\nation\libyan.ruleset"
  Delete "$INSTDIR\data\nation\liechtensteiner.ruleset"
  Delete "$INSTDIR\data\nation\lipkatatar.ruleset"
  Delete "$INSTDIR\data\nation\lithuanian.ruleset"
  Delete "$INSTDIR\data\nation\lojbanistani.ruleset"
  Delete "$INSTDIR\data\nation\lorrain.ruleset"
  Delete "$INSTDIR\data\nation\luxembourgish.ruleset"
  Delete "$INSTDIR\data\nation\maasai.ruleset"
  Delete "$INSTDIR\data\nation\macedon.ruleset"
  Delete "$INSTDIR\data\nation\macedonian.ruleset"
  Delete "$INSTDIR\data\nation\majapahit.ruleset"
  Delete "$INSTDIR\data\nation\malagasy.ruleset"
  Delete "$INSTDIR\data\nation\malawian.ruleset"
  Delete "$INSTDIR\data\nation\malaysian.ruleset"
  Delete "$INSTDIR\data\nation\mali.ruleset"
  Delete "$INSTDIR\data\nation\malian.ruleset"
  Delete "$INSTDIR\data\nation\maltese.ruleset"
  Delete "$INSTDIR\data\nation\manchu.ruleset"
  Delete "$INSTDIR\data\nation\manx.ruleset"
  Delete "$INSTDIR\data\nation\maori.ruleset"
  Delete "$INSTDIR\data\nation\mapuche.ruleset"
  Delete "$INSTDIR\data\nation\martian.ruleset"
  Delete "$INSTDIR\data\nation\mayan.ruleset"
  Delete "$INSTDIR\data\nation\mazovian.ruleset"
  Delete "$INSTDIR\data\nation\mecklenburgian.ruleset"
  Delete "$INSTDIR\data\nation\metis.ruleset"
  Delete "$INSTDIR\data\nation\mexican.ruleset"
  Delete "$INSTDIR\data\nation\miao.ruleset"
  Delete "$INSTDIR\data\nation\micronesian.ruleset"
  Delete "$INSTDIR\data\nation\mikmaq.ruleset"
  Delete "$INSTDIR\data\nation\milanese.ruleset"
  Delete "$INSTDIR\data\nation\miskito.ruleset"
  Delete "$INSTDIR\data\nation\mixtec.ruleset"
  Delete "$INSTDIR\data\nation\moldovan.ruleset"
  Delete "$INSTDIR\data\nation\monegasque.ruleset"
  Delete "$INSTDIR\data\nation\mongol.ruleset"
  Delete "$INSTDIR\data\nation\montenegrin.ruleset"
  Delete "$INSTDIR\data\nation\moravian.ruleset"
  Delete "$INSTDIR\data\nation\mordvin.ruleset"
  Delete "$INSTDIR\data\nation\moroccan.ruleset"
  Delete "$INSTDIR\data\nation\motswana.ruleset"
  Delete "$INSTDIR\data\nation\mozambican.ruleset"
  Delete "$INSTDIR\data\nation\mughal.ruleset"
  Delete "$INSTDIR\data\nation\muskogee.ruleset"
  Delete "$INSTDIR\data\nation\mwiska.ruleset"
  Delete "$INSTDIR\data\nation\namibian.ruleset"
  Delete "$INSTDIR\data\nation\navajo.ruleset"
  Delete "$INSTDIR\data\nation\neapolitan.ruleset"
  Delete "$INSTDIR\data\nation\nepali.ruleset"
  Delete "$INSTDIR\data\nation\nestorian.ruleset"
  Delete "$INSTDIR\data\nation\newfoundland.ruleset"
  Delete "$INSTDIR\data\nation\newzealand.ruleset"
  Delete "$INSTDIR\data\nation\nicaraguan.ruleset"
  Delete "$INSTDIR\data\nation\nigerian.ruleset"
  Delete "$INSTDIR\data\nation\nigerien.ruleset"
  Delete "$INSTDIR\data\nation\nimiipuu.ruleset"
  Delete "$INSTDIR\data\nation\norman.ruleset"
  Delete "$INSTDIR\data\nation\northkorean.ruleset"
  Delete "$INSTDIR\data\nation\northumbrian.ruleset"
  Delete "$INSTDIR\data\nation\norwegian.ruleset"
  Delete "$INSTDIR\data\nation\nubian.ruleset"
  Delete "$INSTDIR\data\nation\numidian.ruleset"
  Delete "$INSTDIR\data\nation\nuu-chah-nulth.ruleset"
  Delete "$INSTDIR\data\nation\occitan.ruleset"
  Delete "$INSTDIR\data\nation\ohlone.ruleset"
  Delete "$INSTDIR\data\nation\oldenburgian.ruleset"
  Delete "$INSTDIR\data\nation\omani.ruleset"
  Delete "$INSTDIR\data\nation\ossetian.ruleset"
  Delete "$INSTDIR\data\nation\ostrogothic.ruleset"
  Delete "$INSTDIR\data\nation\otomi.ruleset"
  Delete "$INSTDIR\data\nation\ottoman.ruleset"
  Delete "$INSTDIR\data\nation\ozite.ruleset"
  Delete "$INSTDIR\data\nation\pakistani.ruleset"
  Delete "$INSTDIR\data\nation\palatinate.ruleset"
  Delete "$INSTDIR\data\nation\palestinian.ruleset"
  Delete "$INSTDIR\data\nation\palmyrene.ruleset"
  Delete "$INSTDIR\data\nation\panamanian.ruleset"
  Delete "$INSTDIR\data\nation\papuan.ruleset"
  Delete "$INSTDIR\data\nation\paraguayan.ruleset"
  Delete "$INSTDIR\data\nation\pashtun.ruleset"
  Delete "$INSTDIR\data\nation\persian.ruleset"
  Delete "$INSTDIR\data\nation\peruvian.ruleset"
  Delete "$INSTDIR\data\nation\phoenician.ruleset"
  Delete "$INSTDIR\data\nation\piedmontese.ruleset"
  Delete "$INSTDIR\data\nation\pirate.ruleset"
  Delete "$INSTDIR\data\nation\polish.ruleset"
  Delete "$INSTDIR\data\nation\polynesian.ruleset"
  Delete "$INSTDIR\data\nation\portuguese.ruleset"
  Delete "$INSTDIR\data\nation\prussian.ruleset"
  Delete "$INSTDIR\data\nation\puertorican.ruleset"
  Delete "$INSTDIR\data\nation\purhepecha.ruleset"
  Delete "$INSTDIR\data\nation\quebecois.ruleset"
  Delete "$INSTDIR\data\nation\raramuri.ruleset"
  Delete "$INSTDIR\data\nation\riffian.ruleset"
  Delete "$INSTDIR\data\nation\riograndense.ruleset"
  Delete "$INSTDIR\data\nation\roman.ruleset"
  Delete "$INSTDIR\data\nation\romanian.ruleset"
  Delete "$INSTDIR\data\nation\russian.ruleset"
  Delete "$INSTDIR\data\nation\ruthenian.ruleset"
  Delete "$INSTDIR\data\nation\rwandan.ruleset"
  Delete "$INSTDIR\data\nation\ryukyuan.ruleset"
  Delete "$INSTDIR\data\nation\sahrawi.ruleset"
  Delete "$INSTDIR\data\nation\salvadoran.ruleset"
  Delete "$INSTDIR\data\nation\sami.ruleset"
  Delete "$INSTDIR\data\nation\sammarinese.ruleset"
  Delete "$INSTDIR\data\nation\samogitian.ruleset"
  Delete "$INSTDIR\data\nation\sarmatian.ruleset"
  Delete "$INSTDIR\data\nation\saudi.ruleset"
  Delete "$INSTDIR\data\nation\savoyard.ruleset"
  Delete "$INSTDIR\data\nation\saxon.ruleset"
  Delete "$INSTDIR\data\nation\schleswig-holsteinian.ruleset"
  Delete "$INSTDIR\data\nation\scottish.ruleset"
  Delete "$INSTDIR\data\nation\scythian.ruleset"
  Delete "$INSTDIR\data\nation\seleucid.ruleset"
  Delete "$INSTDIR\data\nation\senegalese.ruleset"
  Delete "$INSTDIR\data\nation\serbian.ruleset"
  Delete "$INSTDIR\data\nation\shawnee.ruleset"
  Delete "$INSTDIR\data\nation\siberian.ruleset"
  Delete "$INSTDIR\data\nation\sicilian.ruleset"
  Delete "$INSTDIR\data\nation\sikh.ruleset"
  Delete "$INSTDIR\data\nation\sikkimese.ruleset"
  Delete "$INSTDIR\data\nation\silesian.ruleset"
  Delete "$INSTDIR\data\nation\singaporean.ruleset"
  Delete "$INSTDIR\data\nation\sioux.ruleset"
  Delete "$INSTDIR\data\nation\slavic.ruleset"
  Delete "$INSTDIR\data\nation\slovakian.ruleset"
  Delete "$INSTDIR\data\nation\slovenian.ruleset"
  Delete "$INSTDIR\data\nation\somali.ruleset"
  Delete "$INSTDIR\data\nation\songhai.ruleset"
  Delete "$INSTDIR\data\nation\sorbian.ruleset"
  Delete "$INSTDIR\data\nation\southafrican.ruleset"
  Delete "$INSTDIR\data\nation\southamerican.ruleset"
  Delete "$INSTDIR\data\nation\southkorean.ruleset"
  Delete "$INSTDIR\data\nation\southvietnamese.ruleset"
  Delete "$INSTDIR\data\nation\southyemeni.ruleset"
  Delete "$INSTDIR\data\nation\soviet.ruleset"
  Delete "$INSTDIR\data\nation\spanish.ruleset"
  Delete "$INSTDIR\data\nation\srivijaya.ruleset"
  Delete "$INSTDIR\data\nation\sudanese.ruleset"
  Delete "$INSTDIR\data\nation\sumerian.ruleset"
  Delete "$INSTDIR\data\nation\surinamese.ruleset"
  Delete "$INSTDIR\data\nation\swazi.ruleset"
  Delete "$INSTDIR\data\nation\swedish.ruleset"
  Delete "$INSTDIR\data\nation\swiss.ruleset"
  Delete "$INSTDIR\data\nation\syrian.ruleset"
  Delete "$INSTDIR\data\nation\taino.ruleset"
  Delete "$INSTDIR\data\nation\tairona.ruleset"
  Delete "$INSTDIR\data\nation\taiwanese.ruleset"
  Delete "$INSTDIR\data\nation\tajik.ruleset"
  Delete "$INSTDIR\data\nation\tanzanian.ruleset"
  Delete "$INSTDIR\data\nation\tatar.ruleset"
  Delete "$INSTDIR\data\nation\templar.ruleset"
  Delete "$INSTDIR\data\nation\teutonic.ruleset"
  Delete "$INSTDIR\data\nation\texan.ruleset"
  Delete "$INSTDIR\data\nation\thai.ruleset"
  Delete "$INSTDIR\data\nation\thracian.ruleset"
  Delete "$INSTDIR\data\nation\tibetan.ruleset"
  Delete "$INSTDIR\data\nation\timurid.ruleset"
  Delete "$INSTDIR\data\nation\tocharian.ruleset"
  Delete "$INSTDIR\data\nation\togolese.ruleset"
  Delete "$INSTDIR\data\nation\toltec.ruleset"
  Delete "$INSTDIR\data\nation\tongan.ruleset"
  Delete "$INSTDIR\data\nation\transylvanian.ruleset"
  Delete "$INSTDIR\data\nation\tunisian.ruleset"
  Delete "$INSTDIR\data\nation\tupi.ruleset"
  Delete "$INSTDIR\data\nation\turk.ruleset"
  Delete "$INSTDIR\data\nation\turkmen.ruleset"
  Delete "$INSTDIR\data\nation\tuvan.ruleset"
  Delete "$INSTDIR\data\nation\tyrolian.ruleset"
  Delete "$INSTDIR\data\nation\ugandan.ruleset"
  Delete "$INSTDIR\data\nation\ukrainian.ruleset"
  Delete "$INSTDIR\data\nation\un.ruleset"
  Delete "$INSTDIR\data\nation\uruguayan.ruleset"
  Delete "$INSTDIR\data\nation\uyghur.ruleset"
  Delete "$INSTDIR\data\nation\uzbek.ruleset"
  Delete "$INSTDIR\data\nation\vampire.ruleset"
  Delete "$INSTDIR\data\nation\vandalic.ruleset"
  Delete "$INSTDIR\data\nation\venetian.ruleset"
  Delete "$INSTDIR\data\nation\venezuelan.ruleset"
  Delete "$INSTDIR\data\nation\vermont.ruleset"
  Delete "$INSTDIR\data\nation\vietnamese.ruleset"
  Delete "$INSTDIR\data\nation\viking.ruleset"
  Delete "$INSTDIR\data\nation\vincentian.ruleset"
  Delete "$INSTDIR\data\nation\visigothic.ruleset"
  Delete "$INSTDIR\data\nation\walloon.ruleset"
  Delete "$INSTDIR\data\nation\welsh.ruleset"
  Delete "$INSTDIR\data\nation\westernpomeranian.ruleset"
  Delete "$INSTDIR\data\nation\westernroman.ruleset"
  Delete "$INSTDIR\data\nation\westindian.ruleset"
  Delete "$INSTDIR\data\nation\westphalian.ruleset"
  Delete "$INSTDIR\data\nation\wuerttembergian.ruleset"
  Delete "$INSTDIR\data\nation\yakut.ruleset"
  Delete "$INSTDIR\data\nation\yemeni.ruleset"
  Delete "$INSTDIR\data\nation\yucatecan.ruleset"
  Delete "$INSTDIR\data\nation\yugoslav.ruleset"
  Delete "$INSTDIR\data\nation\zapotec.ruleset"
  Delete "$INSTDIR\data\nation\zimbabwean.ruleset"
  Delete "$INSTDIR\data\nation\zulu.ruleset"
  Delete "$INSTDIR\data\scenario\british-isles-85x80-v2.80.sav.gz"
  Delete "$INSTDIR\data\scenario\earth-160x90-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\earth-80x50-v3.sav.gz"
  Delete "$INSTDIR\data\scenario\europe-200x100-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\france-140x90-v2.sav.gz"
  Delete "$INSTDIR\data\scenario\hagworld-120x60-v1.2.sav.gz"
  Delete "$INSTDIR\data\scenario\iberian-peninsula-136x100-v1.0.sav.gz"
  Delete "$INSTDIR\data\scenario\italy-100x100-v1.5.sav.gz"
  Delete "$INSTDIR\data\scenario\japan-88x100-v1.3.sav.gz"
  Delete "$INSTDIR\data\scenario\north_america_116x100-v1.2.sav.gz"
  Delete "$INSTDIR\data\scenario\tutorial.sav.gz"
  Delete "$INSTDIR\data\stdsounds\foot3.ogg"
  Delete "$INSTDIR\data\stdsounds\inh2o.ogg"
  Delete "$INSTDIR\data\stdsounds\LrgCan.ogg"
  Delete "$INSTDIR\data\stdsounds\LrgExpl.ogg"
  Delete "$INSTDIR\data\stdsounds\MedCan.ogg"
  Delete "$INSTDIR\data\stdsounds\metbrk.ogg"
  Delete "$INSTDIR\data\stdsounds\MgBar1.ogg"
  Delete "$INSTDIR\data\stdsounds\MgBar2.ogg"
  Delete "$INSTDIR\data\stdsounds\MgHeavy.ogg"
  Delete "$INSTDIR\data\stdsounds\Mortar.ogg"
  Delete "$INSTDIR\data\stdsounds\SmlExpl.ogg"
  Delete "$INSTDIR\data\stdsounds\Splash.ogg"
  Delete "$INSTDIR\data\stdsounds\THover.ogg"
  Delete "$INSTDIR\data\stdsounds\Tread.ogg"
  Delete "$INSTDIR\data\stdsounds\wall01.ogg"
  Delete "$INSTDIR\data\stdsounds\woodbrk.ogg"
  Delete "$INSTDIR\data\stdsounds.soundspec"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows\arrow-down.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows\arrow-left.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows\arrow-right-norm.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows\arrow-right-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows\arrow-right.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows\arrow-up.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\bg.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Buttons\button-default.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Buttons\button-insensitive.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Buttons\button-normal.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Buttons\button-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Buttons\button-pressed.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\check1.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\check2.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\check3.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\check4.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\checklight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\highlight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\option1.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\option2.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\option3.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio\option4.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo\combo-arrow-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo\combo-arrow-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo\combo-arrow.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo\combo-inactive.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo\combo-normal.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo\combo-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Frame-Gap\frame-gap-end.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Frame-Gap\frame-gap-start.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Frame-Gap\frame1.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Frame-Gap\frame2.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\gtkrc"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Handles\handle-h.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Handles\handle-v.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Lines\line-h.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Lines\line-v.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ListHeaders\list_header-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ListHeaders\list_header-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ListHeaders\list_header-pressed.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ListHeaders\list_header.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar\menu-overlay.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar\menu.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar\menubar-item.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar\menubar.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar\menuitem.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar\menuline.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\menubar.rc"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Others\focus.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Others\null.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Others\ruler.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Panel\panel-bg.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Panel\panelbutton1.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Panel\panelbutton2.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Panel\panelbutton3.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Panel\panelbutton4.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\panel.rc"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar\progressbar-horiz-1.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar\progressbar-horiz-2.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar\progressbar-horiz.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar\t-progressbar-horiz-2.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar\t-progressbar-horiz.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar\t-progressbar-vert.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\null.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\slider-horiz-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\slider-horiz.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\slider-vert-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\slider-vert.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\trough-horizontal.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range\trough-vertical.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\scroll-thumb-horiz.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\scroll-thumb-vert.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\slider-horiz-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\slider-horiz-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\slider-horiz.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\slider-vert-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\slider-vert-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\slider-vert.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-down-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-down-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-down.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-left-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-left-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-left.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-right-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-right-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-right.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-up-insens.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-up-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper-up.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\stepper.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\trough-scrollbar-horiz.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars\trough-scrollbar-vert.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\entry-shadow-in.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\shadow-etched-out.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\shadow-in.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\shadow-none.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\shadow-out.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\text-entry.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows\text.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin-down-disable.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin-down-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin-down.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin-up-disable.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin-up-prelight.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin-up.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin\spin.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\notebook.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\null.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-bottom-active.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-bottom.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-left-active.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-left.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-right-active.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-right.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-top-active.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs\tab-top.png"
  Delete "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Toolbar\toolbar.png"
  Delete "$INSTDIR\data\trident\auto_ll.spec"
  Delete "$INSTDIR\data\trident\cities.png"
  Delete "$INSTDIR\data\trident\cities.spec"
  Delete "$INSTDIR\data\trident\earth.png"
  Delete "$INSTDIR\data\trident\earth.spec"
  Delete "$INSTDIR\data\trident\explosions.png"
  Delete "$INSTDIR\data\trident\explosions.spec"
  Delete "$INSTDIR\data\trident\fog.png"
  Delete "$INSTDIR\data\trident\fog.spec"
  Delete "$INSTDIR\data\trident\grid.png"
  Delete "$INSTDIR\data\trident\grid.spec"
  Delete "$INSTDIR\data\trident\roads.png"
  Delete "$INSTDIR\data\trident\roads.spec"
  Delete "$INSTDIR\data\trident\select.png"
  Delete "$INSTDIR\data\trident\select.spec"
  Delete "$INSTDIR\data\trident\tiles.png"
  Delete "$INSTDIR\data\trident\tiles.spec"
  Delete "$INSTDIR\data\trident\units.png"
  Delete "$INSTDIR\data\trident\units.spec"
  Delete "$INSTDIR\data\trident.tilespec"
  Delete "$INSTDIR\data\wonders\apollo_program.png"
  Delete "$INSTDIR\data\wonders\asmiths_trading_co.png"
  Delete "$INSTDIR\data\wonders\colossus.png"
  Delete "$INSTDIR\data\wonders\copernicus_observatory.png"
  Delete "$INSTDIR\data\wonders\cure_for_cancer.png"
  Delete "$INSTDIR\data\wonders\darwins_voyage.png"
  Delete "$INSTDIR\data\wonders\eiffel_tower.png"
  Delete "$INSTDIR\data\wonders\great_library.png"
  Delete "$INSTDIR\data\wonders\great_wall.png"
  Delete "$INSTDIR\data\wonders\hanging_gardens.png"
  Delete "$INSTDIR\data\wonders\hoover_dam.png"
  Delete "$INSTDIR\data\wonders\isaac_newtons_college.png"
  Delete "$INSTDIR\data\wonders\js_bachs_cathedral.png"
  Delete "$INSTDIR\data\wonders\king_richards_crusade.png"
  Delete "$INSTDIR\data\wonders\leonardos_workshop.png"
  Delete "$INSTDIR\data\wonders\lighthouse.png"
  Delete "$INSTDIR\data\wonders\magellans_expedition.png"
  Delete "$INSTDIR\data\wonders\manhattan_project.png"
  Delete "$INSTDIR\data\wonders\marco_polos_embassy.png"
  Delete "$INSTDIR\data\wonders\michelangelos_chapel.png"
  Delete "$INSTDIR\data\wonders\oracle.png"
  Delete "$INSTDIR\data\wonders\pyramids.png"
  Delete "$INSTDIR\data\wonders\seti_program.png"
  Delete "$INSTDIR\data\wonders\shakespeares_theatre.png"
  Delete "$INSTDIR\data\wonders\statue_of_liberty.png"
  Delete "$INSTDIR\data\wonders\sun_tzus_war_academy.png"
  Delete "$INSTDIR\data\wonders\united_nations.png"
  Delete "$INSTDIR\data\wonders\womens_suffrage.png"
  Delete "$INSTDIR\doc\BUGS"
  Delete "$INSTDIR\doc\ca\BUGS.ca"
  Delete "$INSTDIR\doc\ca\HOWTOPLAY.ca"
  Delete "$INSTDIR\doc\ca\README.ca"
  Delete "$INSTDIR\doc\CodingStyle"
  Delete "$INSTDIR\doc\de\BUGS.de"
  Delete "$INSTDIR\doc\de\HOWTOPLAY.de"
  Delete "$INSTDIR\doc\de\INSTALL.de"
  Delete "$INSTDIR\doc\de\README.de"
  Delete "$INSTDIR\doc\FAQ"
  Delete "$INSTDIR\doc\fr\BUGS.fr"
  Delete "$INSTDIR\doc\fr\HOWTOPLAY.fr"
  Delete "$INSTDIR\doc\fr\INSTALL.fr"
  Delete "$INSTDIR\doc\fr\README.fr"
  Delete "$INSTDIR\doc\HACKING"
  Delete "$INSTDIR\doc\HOWTOPLAY"
  Delete "$INSTDIR\doc\INSTALL.Cygwin"
  Delete "$INSTDIR\doc\it\HOWTOPLAY.it"
  Delete "$INSTDIR\doc\it\INSTALL.it"
  Delete "$INSTDIR\doc\it\README.it"
  Delete "$INSTDIR\doc\ja\BUGS.ja"
  Delete "$INSTDIR\doc\ja\HOWTOPLAY.ja"
  Delete "$INSTDIR\doc\ja\README.ja"
  Delete "$INSTDIR\doc\man\freeciv-client.6.in"
  Delete "$INSTDIR\doc\man\freeciv-ftwl.6"
  Delete "$INSTDIR\doc\man\freeciv-gtk2.6"
  Delete "$INSTDIR\doc\man\freeciv-sdl.6"
  Delete "$INSTDIR\doc\man\freeciv-server.6.in"
  Delete "$INSTDIR\doc\man\freeciv-win32.6"
  Delete "$INSTDIR\doc\man\freeciv-xaw.6"
  Delete "$INSTDIR\doc\nl\BUGS.nl"
  Delete "$INSTDIR\doc\nl\HOWTOPLAY.nl"
  Delete "$INSTDIR\doc\nl\README.nl"
  Delete "$INSTDIR\doc\README"
  Delete "$INSTDIR\doc\README.agents"
  Delete "$INSTDIR\doc\README.AI"
  Delete "$INSTDIR\doc\README.attributes"
  Delete "$INSTDIR\doc\README.cma"
  Delete "$INSTDIR\doc\README.delta"
  Delete "$INSTDIR\doc\README.effects"
  Delete "$INSTDIR\doc\README.ftwl"
  Delete "$INSTDIR\doc\README.graphics"
  Delete "$INSTDIR\doc\README.nations"
  Delete "$INSTDIR\doc\README.packaging"
  Delete "$INSTDIR\doc\README.rulesets"
  Delete "$INSTDIR\doc\README.scorelog"
  Delete "$INSTDIR\doc\README.SDLClient"
  Delete "$INSTDIR\doc\README.sound"
  Delete "$INSTDIR\doc\sv\BUGS.sv"
  Delete "$INSTDIR\doc\sv\HOWTOPLAY.sv"
  Delete "$INSTDIR\doc\sv\README.sv"
  Delete "$INSTDIR\doc\TODO"
  Delete "$INSTDIR\etc\gtk-2.0\gdk-pixbuf.loaders"
  Delete "$INSTDIR\etc\gtk-2.0\gtk.immodules"
  Delete "$INSTDIR\etc\gtk-2.0\im-multipress.conf"
  Delete "$INSTDIR\exchndl.dll"
  Delete "$INSTDIR\freeciv-gtk2.exe"
  Delete "$INSTDIR\freeciv-manual.exe"
  Delete "$INSTDIR\freeciv-modpack.exe"
  Delete "$INSTDIR\freeciv-server.exe"
  Delete "$INSTDIR\Freeciv.url"
  Delete "$INSTDIR\iconv.dll"
  Delete "$INSTDIR\INSTALL"
  Delete "$INSTDIR\intl.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\engines\libpixmap.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\engines\libwimp.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-ani.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-bmp.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-gif.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-icns.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-ico.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-jpeg.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-pcx.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-png.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-pnm.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-ras.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-tga.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-tiff.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-wbmp.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-xbm.dll"
  Delete "$INSTDIR\lib\gtk-2.0\2.10.0\loaders\libpixbufloader-xpm.dll"
  Delete "$INSTDIR\libatk-1.0-0.dll"
  Delete "$INSTDIR\libcairo-2.dll"
  Delete "$INSTDIR\libgdk-win32-2.0-0.dll"
  Delete "$INSTDIR\libgdk_pixbuf-2.0-0.dll"
  Delete "$INSTDIR\libgio-2.0-0.dll"
  Delete "$INSTDIR\libglib-2.0-0.dll"
  Delete "$INSTDIR\libgmodule-2.0-0.dll"
  Delete "$INSTDIR\libgobject-2.0-0.dll"
  Delete "$INSTDIR\libgtk-win32-2.0-0.dll"
  Delete "$INSTDIR\libogg-0.dll"
  Delete "$INSTDIR\libpango-1.0-0.dll"
  Delete "$INSTDIR\libpangocairo-1.0-0.dll"
  Delete "$INSTDIR\libpangowin32-1.0-0.dll"
  Delete "$INSTDIR\libpng12-0.dll"
  Delete "$INSTDIR\libvorbis-0.dll"
  Delete "$INSTDIR\libvorbisfile-3.dll"
  Delete "$INSTDIR\NEWS"
  Delete "$INSTDIR\README"
  Delete "$INSTDIR\SDL.dll"
  Delete "$INSTDIR\SDL_mixer.dll"
  Delete "$INSTDIR\share\locale\af\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\af\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\af\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\am\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\am\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\am\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\am\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ang\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ang\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ar\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ar\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ar\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ar\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ar\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\as\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\as\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\as\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\as\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ast\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ast\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\az\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\az\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\az\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\az\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\az_IR\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\az_IR\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\be\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\be\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\be\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\be\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\be\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\be\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\be@latin\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\be@latin\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\be@latin\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\be@latin\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\bg\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\bg\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\bg\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\bg\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\bn\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\bn\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\bn\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\bn\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\bn_IN\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\bn_IN\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\bn_IN\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\bn_IN\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\br\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\br\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\bs\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\bs\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\bs\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\bs\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ca\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ca@valencia\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ca@valencia\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ca@valencia\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ca@valencia\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\crh\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\crh\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\cs\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\cy\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\cy\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\cy\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\cy\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\da\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\de\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\dz\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\dz\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\dz\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\dz\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\el\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\en@boldquot\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\en@boldquot\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\en@quot\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\en@quot\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\en_CA\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\en_CA\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\en_CA\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\en_CA\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\en_GB\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\en_GB\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\en_GB\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\en_GB\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\en_GB\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\eo\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\es\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\et\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\eu\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\eu\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\eu\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\eu\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\eu\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\fa\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\fa\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\fa\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\fa\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\fa\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\fi\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\fr\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ga\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\gl\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\gu\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\gu\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\gu\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\gu\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\he\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\he\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\he\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\he\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\he\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\hi\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\hi\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\hi\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\hi\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\hr\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\hr\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\hr\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\hr\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\hr\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\hu\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\hy\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\hy\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\hy\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ia\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ia\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\id\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\io\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\io\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\is\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\is\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\is\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\is\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\it\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ja\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ka\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ka\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ka\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ka\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\kn\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\kn\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\kn\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\kn\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ko\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ku\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ku\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ku\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ku\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\li\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\li\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\li\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\lt\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\lt\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\lt\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\lt\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\lt\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\lv\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\lv\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\lv\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\lv\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\mai\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\mai\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\mai\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\mai\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\mg\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\mi\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\mi\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\mk\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\mk\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\mk\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\mk\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ml\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ml\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ml\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ml\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\mn\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\mn\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\mn\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\mn\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\mr\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\mr\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\mr\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\mr\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ms\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ms\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ms\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ms\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\nb\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ne\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ne\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ne\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ne\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\nl\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\nn\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\nn\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\nn\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\nn\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\nn\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\nn\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\no\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\nso\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\nso\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\oc\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\oc\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\oc\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\oc\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\or\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\or\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\or\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\or\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\pa\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\pa\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\pa\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\pa\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\pl\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ps\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ps\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ps\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ps\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\pt\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\pt_BR\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ro\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ru\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\rw\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\rw\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\rw\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\rw\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\si\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\si\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\si\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\si\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sk\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sl\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\sq\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sq\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sq\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sq\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sr\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sr\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\sr\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\sr\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sr\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sr\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sr@ije\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sr@ije\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sr@ije\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sr@ije\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sr@latin\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sr@latin\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sr@latin\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sr@latin\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\sv\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ta\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\ta\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\ta\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ta\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\te\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\te\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\te\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\te\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\th\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\th\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\th\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\th\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\tk\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\tk\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\tk\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\tl\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\tr\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\tt\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\tt\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\tt\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\tt\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\ug\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\uk\LC_MESSAGES\libiconv.mo"
  Delete "$INSTDIR\share\locale\ur\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\ur\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\uz\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\uz\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\uz@cyrillic\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\uz@cyrillic\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\vi\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\vi\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\vi\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\vi\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\vi\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\vi\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\wa\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\wa\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\wa\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\wa\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\xh\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\xh\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\xh\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\xh\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\yi\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\yi\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\yi\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\yi\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\freeciv.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\zh_CN\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\zh_HK\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\zh_HK\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\zh_HK\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\zh_HK\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\zh_HK\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\locale\zh_TW\LC_MESSAGES\atk10.mo"
  Delete "$INSTDIR\share\locale\zh_TW\LC_MESSAGES\gettext-runtime.mo"
  Delete "$INSTDIR\share\locale\zh_TW\LC_MESSAGES\gettext-tools.mo"
  Delete "$INSTDIR\share\locale\zh_TW\LC_MESSAGES\glib20.mo"
  Delete "$INSTDIR\share\locale\zh_TW\LC_MESSAGES\gtk20-properties.mo"
  Delete "$INSTDIR\share\locale\zh_TW\LC_MESSAGES\gtk20.mo"
  Delete "$INSTDIR\share\themes\Default\gtk-2.0-key\gtkrc"
  Delete "$INSTDIR\share\themes\Emacs\gtk-2.0-key\gtkrc"
  Delete "$INSTDIR\share\themes\MS-Windows\gtk-2.0\gtkrc"
  Delete "$INSTDIR\share\themes\Raleigh\gtk-2.0\gtkrc"
  Delete "$INSTDIR\zlib1.dll"
  RMDir "$INSTDIR\data\amplio2"
  RMDir "$INSTDIR\data\buildings"
  RMDir "$INSTDIR\data\civ1"
  RMDir "$INSTDIR\data\civ2"
  RMDir "$INSTDIR\data\default"
  RMDir "$INSTDIR\data\experimental"
  RMDir "$INSTDIR\data\flags"
  RMDir "$INSTDIR\data\hex2t"
  RMDir "$INSTDIR\data\isophex"
  RMDir "$INSTDIR\data\isotrident"
  RMDir "$INSTDIR\data\misc"
  RMDir "$INSTDIR\data\multiplayer"
  RMDir "$INSTDIR\data\nation"
  RMDir "$INSTDIR\data\scenario"
  RMDir "$INSTDIR\data\stdsounds"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Arrows"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Buttons"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Check-Radio"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Combo"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Frame-Gap"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Handles"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Lines"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ListHeaders"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Menu-Menubar"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Others"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Panel"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\ProgressBar"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Range"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Scrollbars"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Shadows"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Spin"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Tabs"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0\Toolbar"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv\gtk-2.0"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0\Freeciv"
  RMDir "$INSTDIR\data\themes\gui-gtk-2.0"
  RMDir "$INSTDIR\data\themes"
  RMDir "$INSTDIR\data\trident"
  RMDir "$INSTDIR\data\wonders"
  RMDir "$INSTDIR\data"
  RMDir "$INSTDIR\doc\ca"
  RMDir "$INSTDIR\doc\de"
  RMDir "$INSTDIR\doc\fr"
  RMDir "$INSTDIR\doc\it"
  RMDir "$INSTDIR\doc\ja"
  RMDir "$INSTDIR\doc\man"
  RMDir "$INSTDIR\doc\nl"
  RMDir "$INSTDIR\doc\sv"
  RMDir "$INSTDIR\doc"
  RMDir "$INSTDIR\etc\gtk-2.0"
  RMDir "$INSTDIR\etc"
  RMDir "$INSTDIR\lib\gtk-2.0\2.10.0\engines"
  RMDir "$INSTDIR\lib\gtk-2.0\2.10.0\loaders"
  RMDir "$INSTDIR\lib\gtk-2.0\2.10.0"
  RMDir "$INSTDIR\lib\gtk-2.0"
  RMDir "$INSTDIR\lib"
  RMDir "$INSTDIR\share\locale\af\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\af"
  RMDir "$INSTDIR\share\locale\am\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\am"
  RMDir "$INSTDIR\share\locale\ang\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ang"
  RMDir "$INSTDIR\share\locale\ar\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ar"
  RMDir "$INSTDIR\share\locale\as\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\as"
  RMDir "$INSTDIR\share\locale\ast\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ast"
  RMDir "$INSTDIR\share\locale\az\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\az"
  RMDir "$INSTDIR\share\locale\az_IR\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\az_IR"
  RMDir "$INSTDIR\share\locale\be\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\be"
  RMDir "$INSTDIR\share\locale\be@latin\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\be@latin"
  RMDir "$INSTDIR\share\locale\bg\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\bg"
  RMDir "$INSTDIR\share\locale\bn\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\bn"
  RMDir "$INSTDIR\share\locale\bn_IN\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\bn_IN"
  RMDir "$INSTDIR\share\locale\br\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\br"
  RMDir "$INSTDIR\share\locale\bs\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\bs"
  RMDir "$INSTDIR\share\locale\ca\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ca"
  RMDir "$INSTDIR\share\locale\ca@valencia\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ca@valencia"
  RMDir "$INSTDIR\share\locale\crh\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\crh"
  RMDir "$INSTDIR\share\locale\cs\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\cs"
  RMDir "$INSTDIR\share\locale\cy\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\cy"
  RMDir "$INSTDIR\share\locale\da\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\da"
  RMDir "$INSTDIR\share\locale\de\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\de"
  RMDir "$INSTDIR\share\locale\dz\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\dz"
  RMDir "$INSTDIR\share\locale\el\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\el"
  RMDir "$INSTDIR\share\locale\en@boldquot\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\en@boldquot"
  RMDir "$INSTDIR\share\locale\en@quot\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\en@quot"
  RMDir "$INSTDIR\share\locale\en_CA\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\en_CA"
  RMDir "$INSTDIR\share\locale\en_GB\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\en_GB"
  RMDir "$INSTDIR\share\locale\eo\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\eo"
  RMDir "$INSTDIR\share\locale\es\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\es"
  RMDir "$INSTDIR\share\locale\et\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\et"
  RMDir "$INSTDIR\share\locale\eu\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\eu"
  RMDir "$INSTDIR\share\locale\fa\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\fa"
  RMDir "$INSTDIR\share\locale\fi\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\fi"
  RMDir "$INSTDIR\share\locale\fr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\fr"
  RMDir "$INSTDIR\share\locale\ga\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ga"
  RMDir "$INSTDIR\share\locale\gl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\gl"
  RMDir "$INSTDIR\share\locale\gu\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\gu"
  RMDir "$INSTDIR\share\locale\he\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\he"
  RMDir "$INSTDIR\share\locale\hi\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\hi"
  RMDir "$INSTDIR\share\locale\hr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\hr"
  RMDir "$INSTDIR\share\locale\hu\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\hu"
  RMDir "$INSTDIR\share\locale\hy\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\hy"
  RMDir "$INSTDIR\share\locale\ia\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ia"
  RMDir "$INSTDIR\share\locale\id\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\id"
  RMDir "$INSTDIR\share\locale\io\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\io"
  RMDir "$INSTDIR\share\locale\is\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\is"
  RMDir "$INSTDIR\share\locale\it\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\it"
  RMDir "$INSTDIR\share\locale\ja\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ja"
  RMDir "$INSTDIR\share\locale\ka\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ka"
  RMDir "$INSTDIR\share\locale\kn\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\kn"
  RMDir "$INSTDIR\share\locale\ko\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ko"
  RMDir "$INSTDIR\share\locale\ku\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ku"
  RMDir "$INSTDIR\share\locale\li\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\li"
  RMDir "$INSTDIR\share\locale\lt\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\lt"
  RMDir "$INSTDIR\share\locale\lv\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\lv"
  RMDir "$INSTDIR\share\locale\mai\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\mai"
  RMDir "$INSTDIR\share\locale\mg\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\mg"
  RMDir "$INSTDIR\share\locale\mi\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\mi"
  RMDir "$INSTDIR\share\locale\mk\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\mk"
  RMDir "$INSTDIR\share\locale\ml\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ml"
  RMDir "$INSTDIR\share\locale\mn\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\mn"
  RMDir "$INSTDIR\share\locale\mr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\mr"
  RMDir "$INSTDIR\share\locale\ms\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ms"
  RMDir "$INSTDIR\share\locale\nb\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\nb"
  RMDir "$INSTDIR\share\locale\ne\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ne"
  RMDir "$INSTDIR\share\locale\nl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\nl"
  RMDir "$INSTDIR\share\locale\nn\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\nn"
  RMDir "$INSTDIR\share\locale\no\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\no"
  RMDir "$INSTDIR\share\locale\nso\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\nso"
  RMDir "$INSTDIR\share\locale\oc\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\oc"
  RMDir "$INSTDIR\share\locale\or\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\or"
  RMDir "$INSTDIR\share\locale\pa\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pa"
  RMDir "$INSTDIR\share\locale\pl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pl"
  RMDir "$INSTDIR\share\locale\ps\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ps"
  RMDir "$INSTDIR\share\locale\pt\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pt"
  RMDir "$INSTDIR\share\locale\pt_BR\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\pt_BR"
  RMDir "$INSTDIR\share\locale\ro\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ro"
  RMDir "$INSTDIR\share\locale\ru\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ru"
  RMDir "$INSTDIR\share\locale\rw\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\rw"
  RMDir "$INSTDIR\share\locale\si\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\si"
  RMDir "$INSTDIR\share\locale\sk\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sk"
  RMDir "$INSTDIR\share\locale\sl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sl"
  RMDir "$INSTDIR\share\locale\sq\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sq"
  RMDir "$INSTDIR\share\locale\sr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sr"
  RMDir "$INSTDIR\share\locale\sr@ije\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sr@ije"
  RMDir "$INSTDIR\share\locale\sr@latin\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sr@latin"
  RMDir "$INSTDIR\share\locale\sv\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\sv"
  RMDir "$INSTDIR\share\locale\ta\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ta"
  RMDir "$INSTDIR\share\locale\te\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\te"
  RMDir "$INSTDIR\share\locale\th\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\th"
  RMDir "$INSTDIR\share\locale\tk\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\tk"
  RMDir "$INSTDIR\share\locale\tl\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\tl"
  RMDir "$INSTDIR\share\locale\tr\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\tr"
  RMDir "$INSTDIR\share\locale\tt\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\tt"
  RMDir "$INSTDIR\share\locale\ug\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ug"
  RMDir "$INSTDIR\share\locale\uk\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\uk"
  RMDir "$INSTDIR\share\locale\ur\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\ur"
  RMDir "$INSTDIR\share\locale\uz\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\uz"
  RMDir "$INSTDIR\share\locale\uz@cyrillic\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\uz@cyrillic"
  RMDir "$INSTDIR\share\locale\vi\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\vi"
  RMDir "$INSTDIR\share\locale\wa\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\wa"
  RMDir "$INSTDIR\share\locale\xh\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\xh"
  RMDir "$INSTDIR\share\locale\yi\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\yi"
  RMDir "$INSTDIR\share\locale\zh_CN\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\zh_CN"
  RMDir "$INSTDIR\share\locale\zh_HK\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\zh_HK"
  RMDir "$INSTDIR\share\locale\zh_TW\LC_MESSAGES"
  RMDir "$INSTDIR\share\locale\zh_TW"
  RMDir "$INSTDIR\share\locale"
  RMDir "$INSTDIR\share\themes\Default\gtk-2.0-key"
  RMDir "$INSTDIR\share\themes\Default"
  RMDir "$INSTDIR\share\themes\Emacs\gtk-2.0-key"
  RMDir "$INSTDIR\share\themes\Emacs"
  RMDir "$INSTDIR\share\themes\MS-Windows\gtk-2.0"
  RMDir "$INSTDIR\share\themes\MS-Windows"
  RMDir "$INSTDIR\share\themes\Raleigh\gtk-2.0"
  RMDir "$INSTDIR\share\themes\Raleigh"
  RMDir "$INSTDIR\share\themes"
  RMDir "$INSTDIR\share"
  RMDir "$INSTDIR"

  ; MUST REMOVE UNINSTALLER, too
  Delete $INSTDIR\uninstall.exe

  ; remove shortcuts, if any.
  !insertmacro MUI_STARTMENU_GETFOLDER "Application" $STARTMENU_FOLDER
  Delete "$SMPROGRAMS\$STARTMENU_FOLDER\*.*"
  RMDir "$SMPROGRAMS\$STARTMENU_FOLDER"

  ; remove registry keys
  DeleteRegKey "SHCTX" "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPID}"
  DeleteRegKey /ifempty "SHCTX" SOFTWARE\${APPNAME}\${VERSION}\${GUI_ID}
  DeleteRegKey /ifempty "SHCTX" SOFTWARE\${APPNAME}\${VERSION}
  DeleteRegKey /ifempty "SHCTX" SOFTWARE\${APPNAME}
SectionEnd
;--------------------------------
;Uninstaller Functions

Function un.onInit

  !insertmacro MULTIUSER_UNINIT

FunctionEnd

